# Copyright (c) 2019 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: da/daml_lf_1.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='da/daml_lf_1.proto',
  package='daml_lf_1',
  syntax='proto3',
  serialized_options=_b('\n\030com.digitalasset.daml_lf'),
  serialized_pb=_b('\n\x12\x64\x61/daml_lf_1.proto\x12\tdaml_lf_1\"\x06\n\x04Unit\"J\n\nPackageRef\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00\x12\x14\n\npackage_id\x18\x02 \x01(\tH\x00\x42\x05\n\x03Sum\"\x1e\n\nDottedName\x12\x10\n\x08segments\x18\x01 \x03(\t\"c\n\tModuleRef\x12*\n\x0bpackage_ref\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.PackageRef\x12*\n\x0bmodule_name\x18\x02 \x01(\x0b\x32\x15.daml_lf_1.DottedName\"X\n\x0bTypeConName\x12$\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_1.ModuleRef\x12#\n\x04name\x18\x02 \x01(\x0b\x32\x15.daml_lf_1.DottedName\"=\n\x07ValName\x12$\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_1.ModuleRef\x12\x0c\n\x04name\x18\x02 \x03(\t\"=\n\rFieldWithType\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x1d\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Type\"9\n\x0bVarWithType\x12\x0b\n\x03var\x18\x01 \x01(\t\x12\x1d\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Type\"=\n\x0fTypeVarWithKind\x12\x0b\n\x03var\x18\x01 \x01(\t\x12\x1d\n\x04kind\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Kind\"=\n\rFieldWithExpr\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x1d\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\"Q\n\x07\x42inding\x12&\n\x06\x62inder\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.VarWithType\x12\x1e\n\x05\x62ound\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\"\xa1\x01\n\x04Kind\x12\x1f\n\x04star\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00\x12&\n\x05\x61rrow\x18\x02 \x01(\x0b\x32\x15.daml_lf_1.Kind.ArrowH\x00\x1aI\n\x05\x41rrow\x12\x1f\n\x06params\x18\x01 \x03(\x0b\x32\x0f.daml_lf_1.Kind\x12\x1f\n\x06result\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.KindB\x05\n\x03Sum\"\xa2\x05\n\x04Type\x12\"\n\x03var\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.VarH\x00\x12\"\n\x03\x63on\x18\x02 \x01(\x0b\x32\x13.daml_lf_1.Type.ConH\x00\x12$\n\x04prim\x18\x03 \x01(\x0b\x32\x14.daml_lf_1.Type.PrimH\x00\x12\"\n\x03\x66un\x18\x04 \x01(\x0b\x32\x13.daml_lf_1.Type.FunH\x00\x12(\n\x06\x66orall\x18\x05 \x01(\x0b\x32\x16.daml_lf_1.Type.ForallH\x00\x12&\n\x05tuple\x18\x07 \x01(\x0b\x32\x15.daml_lf_1.Type.TupleH\x00\x1a\x31\n\x03Var\x12\x0b\n\x03var\x18\x01 \x01(\t\x12\x1d\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.Type\x1aK\n\x03\x43on\x12%\n\x05tycon\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x1d\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.Type\x1aH\n\x04Prim\x12!\n\x04prim\x18\x01 \x01(\x0e\x32\x13.daml_lf_1.PrimType\x12\x1d\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.Type\x1aG\n\x03\x46un\x12\x1f\n\x06params\x18\x01 \x03(\x0b\x32\x0f.daml_lf_1.Type\x12\x1f\n\x06result\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Type\x1aQ\n\x06\x46orall\x12(\n\x04vars\x18\x01 \x03(\x0b\x32\x1a.daml_lf_1.TypeVarWithKind\x12\x1d\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Type\x1a\x31\n\x05Tuple\x12(\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_1.FieldWithTypeB\x05\n\x03SumJ\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\x86\x01\n\x07PrimLit\x12\x0f\n\x05int64\x18\x01 \x01(\x12H\x00\x12\x11\n\x07\x64\x65\x63imal\x18\x02 \x01(\tH\x00\x12\x0e\n\x04text\x18\x04 \x01(\tH\x00\x12\x13\n\ttimestamp\x18\x05 \x01(\x10H\x00\x12\x0f\n\x05party\x18\x07 \x01(\tH\x00\x12\x0e\n\x04\x64\x61te\x18\x08 \x01(\x05H\x00\x42\x05\n\x03SumJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07\"\xad\x01\n\x08Location\x12$\n\x06module\x18\x01 \x01(\x0b\x32\x14.daml_lf_1.ModuleRef\x12(\n\x05range\x18\x02 \x01(\x0b\x32\x19.daml_lf_1.Location.Range\x1aQ\n\x05Range\x12\x12\n\nstart_line\x18\x01 \x01(\x05\x12\x11\n\tstart_col\x18\x02 \x01(\x05\x12\x10\n\x08\x65nd_line\x18\x03 \x01(\x05\x12\x0f\n\x07\x65nd_col\x18\x04 \x01(\x05\"\xfd\x11\n\x04\x45xpr\x12%\n\x08location\x18\x19 \x01(\x0b\x32\x13.daml_lf_1.Location\x12\r\n\x03var\x18\x01 \x01(\tH\x00\x12!\n\x03val\x18\x02 \x01(\x0b\x32\x12.daml_lf_1.ValNameH\x00\x12-\n\x07\x62uiltin\x18\x03 \x01(\x0e\x32\x1a.daml_lf_1.BuiltinFunctionH\x00\x12&\n\x08prim_con\x18\x04 \x01(\x0e\x32\x12.daml_lf_1.PrimConH\x00\x12&\n\x08prim_lit\x18\x05 \x01(\x0b\x32\x12.daml_lf_1.PrimLitH\x00\x12)\n\x07rec_con\x18\x06 \x01(\x0b\x32\x16.daml_lf_1.Expr.RecConH\x00\x12+\n\x08rec_proj\x18\x07 \x01(\x0b\x32\x17.daml_lf_1.Expr.RecProjH\x00\x12)\n\x07rec_upd\x18\x16 \x01(\x0b\x32\x16.daml_lf_1.Expr.RecUpdH\x00\x12\x31\n\x0bvariant_con\x18\x08 \x01(\x0b\x32\x1a.daml_lf_1.Expr.VariantConH\x00\x12+\n\x08\x65num_con\x18\x1c \x01(\x0b\x32\x17.daml_lf_1.Expr.EnumConH\x00\x12-\n\ttuple_con\x18\t \x01(\x0b\x32\x18.daml_lf_1.Expr.TupleConH\x00\x12/\n\ntuple_proj\x18\n \x01(\x0b\x32\x19.daml_lf_1.Expr.TupleProjH\x00\x12-\n\ttuple_upd\x18\x17 \x01(\x0b\x32\x18.daml_lf_1.Expr.TupleUpdH\x00\x12\"\n\x03\x61pp\x18\x0b \x01(\x0b\x32\x13.daml_lf_1.Expr.AppH\x00\x12\'\n\x06ty_app\x18\x0c \x01(\x0b\x32\x15.daml_lf_1.Expr.TyAppH\x00\x12\"\n\x03\x61\x62s\x18\r \x01(\x0b\x32\x13.daml_lf_1.Expr.AbsH\x00\x12\'\n\x06ty_abs\x18\x0e \x01(\x0b\x32\x15.daml_lf_1.Expr.TyAbsH\x00\x12\x1f\n\x04\x63\x61se\x18\x0f \x01(\x0b\x32\x0f.daml_lf_1.CaseH\x00\x12\x1f\n\x03let\x18\x10 \x01(\x0b\x32\x10.daml_lf_1.BlockH\x00\x12\"\n\x03nil\x18\x11 \x01(\x0b\x32\x13.daml_lf_1.Expr.NilH\x00\x12$\n\x04\x63ons\x18\x12 \x01(\x0b\x32\x14.daml_lf_1.Expr.ConsH\x00\x12#\n\x06update\x18\x14 \x01(\x0b\x32\x11.daml_lf_1.UpdateH\x00\x12\'\n\x08scenario\x18\x15 \x01(\x0b\x32\x13.daml_lf_1.ScenarioH\x00\x12$\n\x04none\x18\x1a \x01(\x0b\x32\x14.daml_lf_1.Expr.NoneH\x00\x12$\n\x04some\x18\x1b \x01(\x0b\x32\x14.daml_lf_1.Expr.SomeH\x00\x1aV\n\x06RecCon\x12\"\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.Con\x12(\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x18.daml_lf_1.FieldWithExpr\x1a]\n\x07RecProj\x12\"\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.Con\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x1f\n\x06record\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1a}\n\x06RecUpd\x12\"\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.Con\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x1f\n\x06record\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1f\n\x06update\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1ak\n\nVariantCon\x12\"\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.Con\x12\x13\n\x0bvariant_con\x18\x02 \x01(\t\x12$\n\x0bvariant_arg\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1a\x42\n\x07\x45numCon\x12%\n\x05tycon\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x10\n\x08\x65num_con\x18\x02 \x01(\t\x1a\x34\n\x08TupleCon\x12(\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_1.FieldWithExpr\x1a:\n\tTupleProj\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x1e\n\x05tuple\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1aZ\n\x08TupleUpd\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x1e\n\x05tuple\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1f\n\x06update\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1a\x42\n\x03\x41pp\x12\x1c\n\x03\x66un\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1d\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.Expr\x1a\x46\n\x05TyApp\x12\x1d\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1e\n\x05types\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.Type\x1aK\n\x03\x41\x62s\x12%\n\x05param\x18\x01 \x03(\x0b\x32\x16.daml_lf_1.VarWithType\x12\x1d\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1aQ\n\x05TyAbs\x12)\n\x05param\x18\x01 \x03(\x0b\x32\x1a.daml_lf_1.TypeVarWithKind\x12\x1d\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1a$\n\x03Nil\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x1a\x64\n\x04\x43ons\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x12\x1e\n\x05\x66ront\x18\x02 \x03(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1d\n\x04tail\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1a%\n\x04None\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x1a\x44\n\x04Some\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x12\x1d\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprB\x05\n\x03SumJ\x04\x08\x13\x10\x14J\x04\x08\x18\x10\x19\"\xbf\x04\n\x07\x43\x61seAlt\x12\"\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00\x12-\n\x07variant\x18\x02 \x01(\x0b\x32\x1a.daml_lf_1.CaseAlt.VariantH\x00\x12&\n\x08prim_con\x18\x03 \x01(\x0e\x32\x12.daml_lf_1.PrimConH\x00\x12\x1e\n\x03nil\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00\x12\'\n\x04\x63ons\x18\x05 \x01(\x0b\x32\x17.daml_lf_1.CaseAlt.ConsH\x00\x12\x1f\n\x04none\x18\x07 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00\x12\'\n\x04some\x18\x08 \x01(\x0b\x32\x17.daml_lf_1.CaseAlt.SomeH\x00\x12\'\n\x04\x65num\x18\t \x01(\x0b\x32\x17.daml_lf_1.CaseAlt.EnumH\x00\x12\x1d\n\x04\x62ody\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1aO\n\x07Variant\x12#\n\x03\x63on\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12\x0e\n\x06\x62inder\x18\x03 \x01(\t\x1a@\n\x04\x45num\x12#\n\x03\x63on\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x13\n\x0b\x63onstructor\x18\x02 \x01(\t\x1a*\n\x04\x43ons\x12\x10\n\x08var_head\x18\x01 \x01(\t\x12\x10\n\x08var_tail\x18\x02 \x01(\t\x1a\x18\n\x04Some\x12\x10\n\x08var_body\x18\x01 \x01(\tB\x05\n\x03Sum\"H\n\x04\x43\x61se\x12\x1e\n\x05scrut\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12 \n\x04\x61lts\x18\x02 \x03(\x0b\x32\x12.daml_lf_1.CaseAlt\"L\n\x05\x42lock\x12$\n\x08\x62indings\x18\x01 \x03(\x0b\x32\x12.daml_lf_1.Binding\x12\x1d\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\"D\n\x04Pure\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x12\x1d\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\"\x95\x07\n\x06Update\x12\x1f\n\x04pure\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.PureH\x00\x12!\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x10.daml_lf_1.BlockH\x00\x12*\n\x06\x63reate\x18\x03 \x01(\x0b\x32\x18.daml_lf_1.Update.CreateH\x00\x12.\n\x08\x65xercise\x18\x04 \x01(\x0b\x32\x1a.daml_lf_1.Update.ExerciseH\x00\x12(\n\x05\x66\x65tch\x18\x05 \x01(\x0b\x32\x17.daml_lf_1.Update.FetchH\x00\x12#\n\x08get_time\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00\x12\x38\n\rlookup_by_key\x18\x08 \x01(\x0b\x32\x1f.daml_lf_1.Update.RetrieveByKeyH\x00\x12\x37\n\x0c\x66\x65tch_by_key\x18\t \x01(\x0b\x32\x1f.daml_lf_1.Update.RetrieveByKeyH\x00\x12\x31\n\nembed_expr\x18\x07 \x01(\x0b\x32\x1b.daml_lf_1.Update.EmbedExprH\x00\x1aQ\n\x06\x43reate\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x1d\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1a\xa0\x01\n\x08\x45xercise\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x0e\n\x06\x63hoice\x18\x02 \x01(\t\x12\x1c\n\x03\x63id\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1e\n\x05\x61\x63tor\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1c\n\x03\x61rg\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1aU\n\x05\x46\x65tch\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x1c\n\x03\x63id\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprJ\x04\x08\x03\x10\x04\x1aI\n\tEmbedExpr\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x12\x1d\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x1aW\n\rRetrieveByKey\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.daml_lf_1.TypeConName\x12\x1c\n\x03key\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprB\x05\n\x03Sum\"\x8d\x04\n\x08Scenario\x12\x1f\n\x04pure\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.PureH\x00\x12!\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x10.daml_lf_1.BlockH\x00\x12,\n\x06\x63ommit\x18\x03 \x01(\x0b\x32\x1a.daml_lf_1.Scenario.CommitH\x00\x12\x30\n\nmustFailAt\x18\x04 \x01(\x0b\x32\x1a.daml_lf_1.Scenario.CommitH\x00\x12\x1f\n\x04pass\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.ExprH\x00\x12#\n\x08get_time\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.UnitH\x00\x12$\n\tget_party\x18\x07 \x01(\x0b\x32\x0f.daml_lf_1.ExprH\x00\x12\x33\n\nembed_expr\x18\x08 \x01(\x0b\x32\x1d.daml_lf_1.Scenario.EmbedExprH\x00\x1aj\n\x06\x43ommit\x12\x1e\n\x05party\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x1d\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12!\n\x08ret_type\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Type\x1aI\n\tEmbedExpr\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x12\x1d\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.ExprB\x05\n\x03Sum\"\x83\x02\n\x0eTemplateChoice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tconsuming\x18\x02 \x01(\x08\x12$\n\x0b\x63ontrollers\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12*\n\narg_binder\x18\x04 \x01(\x0b\x32\x16.daml_lf_1.VarWithType\x12!\n\x08ret_type\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.Type\x12\x1f\n\x06update\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x13\n\x0bself_binder\x18\x07 \x01(\t\x12%\n\x08location\x18\x08 \x01(\x0b\x32\x13.daml_lf_1.Location\"\x96\x03\n\x07KeyExpr\x12\x35\n\x0bprojections\x18\x01 \x01(\x0b\x32\x1e.daml_lf_1.KeyExpr.ProjectionsH\x00\x12+\n\x06record\x18\x02 \x01(\x0b\x32\x19.daml_lf_1.KeyExpr.RecordH\x00\x1a?\n\nProjection\x12\"\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.Con\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x1a\x41\n\x0bProjections\x12\x32\n\x0bprojections\x18\x02 \x03(\x0b\x32\x1d.daml_lf_1.KeyExpr.Projection\x1a>\n\x0bRecordField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12 \n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x12.daml_lf_1.KeyExpr\x1a\\\n\x06Record\x12\"\n\x05tycon\x18\x01 \x01(\x0b\x32\x13.daml_lf_1.Type.Con\x12.\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x1e.daml_lf_1.KeyExpr.RecordFieldB\x05\n\x03Sum\"\xfe\x03\n\x0b\x44\x65\x66Template\x12$\n\x05tycon\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.DottedName\x12\r\n\x05param\x18\x02 \x01(\t\x12 \n\x07precond\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12$\n\x0bsignatories\x18\x05 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\"\n\tagreement\x18\x06 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12*\n\x07\x63hoices\x18\x07 \x03(\x0b\x32\x19.daml_lf_1.TemplateChoice\x12\"\n\tobservers\x18\x08 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12%\n\x08location\x18\t \x01(\x0b\x32\x13.daml_lf_1.Location\x12*\n\x03key\x18\n \x01(\x0b\x32\x1d.daml_lf_1.DefTemplate.DefKey\x1a\xa4\x01\n\x06\x44\x65\x66Key\x12\x1d\n\x04type\x18\x01 \x01(\x0b\x32\x0f.daml_lf_1.Type\x12!\n\x03key\x18\x02 \x01(\x0b\x32\x12.daml_lf_1.KeyExprH\x00\x12&\n\x0b\x63omplex_key\x18\x04 \x01(\x0b\x32\x0f.daml_lf_1.ExprH\x00\x12$\n\x0bmaintainers\x18\x03 \x01(\x0b\x32\x0f.daml_lf_1.ExprB\n\n\x08key_exprJ\x04\x08\x03\x10\x04\"\xa1\x03\n\x0b\x44\x65\x66\x44\x61taType\x12#\n\x04name\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.DottedName\x12*\n\x06params\x18\x02 \x03(\x0b\x32\x1a.daml_lf_1.TypeVarWithKind\x12/\n\x06record\x18\x03 \x01(\x0b\x32\x1d.daml_lf_1.DefDataType.FieldsH\x00\x12\x30\n\x07variant\x18\x04 \x01(\x0b\x32\x1d.daml_lf_1.DefDataType.FieldsH\x00\x12\x37\n\x04\x65num\x18\x07 \x01(\x0b\x32\'.daml_lf_1.DefDataType.EnumConstructorsH\x00\x12\x14\n\x0cserializable\x18\x05 \x01(\x08\x12%\n\x08location\x18\x06 \x01(\x0b\x32\x13.daml_lf_1.Location\x1a\x32\n\x06\x46ields\x12(\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.daml_lf_1.FieldWithType\x1a(\n\x10\x45numConstructors\x12\x14\n\x0c\x63onstructors\x18\x01 \x03(\tB\n\n\x08\x44\x61taCons\"\xf3\x01\n\x08\x44\x65\x66Value\x12\x38\n\x0ename_with_type\x18\x01 \x01(\x0b\x32 .daml_lf_1.DefValue.NameWithType\x12\x1d\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Expr\x12\x19\n\x11no_party_literals\x18\x03 \x01(\x08\x12\x0f\n\x07is_test\x18\x04 \x01(\x08\x12%\n\x08location\x18\x05 \x01(\x0b\x32\x13.daml_lf_1.Location\x1a;\n\x0cNameWithType\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\x1d\n\x04type\x18\x02 \x01(\x0b\x32\x0f.daml_lf_1.Type\"\x90\x01\n\x0c\x46\x65\x61tureFlags\x12\x1b\n\x13\x66orbidPartyLiterals\x18\x01 \x01(\x08\x12/\n\'dontDivulgeContractIdsInCreateArguments\x18\x02 \x01(\x08\x12\x32\n*dontDiscloseNonConsumingChoicesToObservers\x18\x03 \x01(\x08\"\xdd\x01\n\x06Module\x12#\n\x04name\x18\x01 \x01(\x0b\x32\x15.daml_lf_1.DottedName\x12&\n\x05\x66lags\x18\x04 \x01(\x0b\x32\x17.daml_lf_1.FeatureFlags\x12*\n\ndata_types\x18\x05 \x03(\x0b\x32\x16.daml_lf_1.DefDataType\x12#\n\x06values\x18\x06 \x03(\x0b\x32\x13.daml_lf_1.DefValue\x12)\n\ttemplates\x18\x07 \x03(\x0b\x32\x16.daml_lf_1.DefTemplateJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"-\n\x07Package\x12\"\n\x07modules\x18\x01 \x03(\x0b\x32\x11.daml_lf_1.Module*\xbb\x01\n\x08PrimType\x12\x08\n\x04UNIT\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\x0b\n\x07\x44\x45\x43IMAL\x10\x03\x12\x08\n\x04TEXT\x10\x05\x12\r\n\tTIMESTAMP\x10\x06\x12\t\n\x05PARTY\x10\x08\x12\x08\n\x04LIST\x10\t\x12\n\n\x06UPDATE\x10\n\x12\x0c\n\x08SCENARIO\x10\x0b\x12\x08\n\x04\x44\x41TE\x10\x0c\x12\x0f\n\x0b\x43ONTRACT_ID\x10\r\x12\x0c\n\x08OPTIONAL\x10\x0e\x12\t\n\x05\x41RROW\x10\x0f\x12\x07\n\x03MAP\x10\x10*4\n\x07PrimCon\x12\x0c\n\x08\x43ON_UNIT\x10\x00\x12\r\n\tCON_FALSE\x10\x01\x12\x0c\n\x08\x43ON_TRUE\x10\x02*\x88\x0b\n\x0f\x42uiltinFunction\x12\x0f\n\x0b\x41\x44\x44_DECIMAL\x10\x00\x12\x0f\n\x0bSUB_DECIMAL\x10\x01\x12\x0f\n\x0bMUL_DECIMAL\x10\x02\x12\x0f\n\x0b\x44IV_DECIMAL\x10\x03\x12\x11\n\rROUND_DECIMAL\x10\x06\x12\r\n\tADD_INT64\x10\x07\x12\r\n\tSUB_INT64\x10\x08\x12\r\n\tMUL_INT64\x10\t\x12\r\n\tDIV_INT64\x10\n\x12\r\n\tMOD_INT64\x10\x0b\x12\r\n\tEXP_INT64\x10\x0c\x12\t\n\x05\x46OLDL\x10\x14\x12\t\n\x05\x46OLDR\x10\x15\x12\r\n\tMAP_EMPTY\x10`\x12\x0e\n\nMAP_INSERT\x10\x61\x12\x0e\n\nMAP_LOOKUP\x10\x62\x12\x0e\n\nMAP_DELETE\x10\x63\x12\x0f\n\x0bMAP_TO_LIST\x10\x64\x12\x0c\n\x08MAP_SIZE\x10\x65\x12\x10\n\x0c\x45XPLODE_TEXT\x10\x17\x12\x0f\n\x0b\x41PPEND_TEXT\x10\x18\x12\t\n\x05\x45RROR\x10\x19\x12\r\n\tLEQ_INT64\x10!\x12\x0f\n\x0bLEQ_DECIMAL\x10\"\x12\x0c\n\x08LEQ_TEXT\x10$\x12\x11\n\rLEQ_TIMESTAMP\x10%\x12\x0c\n\x08LEQ_DATE\x10\x43\x12\r\n\tLEQ_PARTY\x10Y\x12\x0e\n\nLESS_INT64\x10\'\x12\x10\n\x0cLESS_DECIMAL\x10(\x12\r\n\tLESS_TEXT\x10*\x12\x12\n\x0eLESS_TIMESTAMP\x10+\x12\r\n\tLESS_DATE\x10\x44\x12\x0e\n\nLESS_PARTY\x10Z\x12\r\n\tGEQ_INT64\x10-\x12\x0f\n\x0bGEQ_DECIMAL\x10.\x12\x0c\n\x08GEQ_TEXT\x10\x30\x12\x11\n\rGEQ_TIMESTAMP\x10\x31\x12\x0c\n\x08GEQ_DATE\x10\x45\x12\r\n\tGEQ_PARTY\x10[\x12\x11\n\rGREATER_INT64\x10\x33\x12\x13\n\x0fGREATER_DECIMAL\x10\x34\x12\x10\n\x0cGREATER_TEXT\x10\x36\x12\x15\n\x11GREATER_TIMESTAMP\x10\x37\x12\x10\n\x0cGREATER_DATE\x10\x46\x12\x11\n\rGREATER_PARTY\x10\\\x12\x11\n\rTO_TEXT_INT64\x10\x39\x12\x13\n\x0fTO_TEXT_DECIMAL\x10:\x12\x10\n\x0cTO_TEXT_TEXT\x10<\x12\x15\n\x11TO_TEXT_TIMESTAMP\x10=\x12\x10\n\x0cTO_TEXT_DATE\x10G\x12\x18\n\x14TO_QUOTED_TEXT_PARTY\x10?\x12\x11\n\rTO_TEXT_PARTY\x10^\x12\x17\n\x13TO_TEXT_CODE_POINTS\x10i\x12\x13\n\x0f\x46ROM_TEXT_PARTY\x10_\x12\x13\n\x0f\x46ROM_TEXT_INT64\x10g\x12\x15\n\x11\x46ROM_TEXT_DECIMAL\x10h\x12\x19\n\x15\x46ROM_TEXT_CODE_POINTS\x10j\x12\x0f\n\x0bSHA256_TEXT\x10]\x12\x15\n\x11\x44\x41TE_TO_UNIX_DAYS\x10H\x12\x15\n\x11UNIX_DAYS_TO_DATE\x10I\x12\"\n\x1eTIMESTAMP_TO_UNIX_MICROSECONDS\x10J\x12\"\n\x1eUNIX_MICROSECONDS_TO_TIMESTAMP\x10K\x12\x14\n\x10INT64_TO_DECIMAL\x10L\x12\x14\n\x10\x44\x45\x43IMAL_TO_INT64\x10M\x12\x10\n\x0cIMPLODE_TEXT\x10N\x12\x0f\n\x0b\x45QUAL_INT64\x10O\x12\x11\n\rEQUAL_DECIMAL\x10P\x12\x0e\n\nEQUAL_TEXT\x10Q\x12\x13\n\x0f\x45QUAL_TIMESTAMP\x10R\x12\x0e\n\nEQUAL_DATE\x10S\x12\x0f\n\x0b\x45QUAL_PARTY\x10T\x12\x0e\n\nEQUAL_BOOL\x10U\x12\x15\n\x11\x45QUAL_CONTRACT_ID\x10V\x12\x0e\n\nEQUAL_LIST\x10W\x12\t\n\x05TRACE\x10X\x12\x16\n\x12\x43OERCE_CONTRACT_ID\x10\x66\x42\x1a\n\x18\x63om.digitalasset.daml_lfb\x06proto3')
)

_PRIMTYPE = _descriptor.EnumDescriptor(
  name='PrimType',
  full_name='daml_lf_1.PrimType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT64', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECIMAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMESTAMP', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTY', index=6, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST', index=7, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=8, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCENARIO', index=9, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=10, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTRACT_ID', index=11, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPTIONAL', index=12, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARROW', index=13, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP', index=14, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8709,
  serialized_end=8896,
)
_sym_db.RegisterEnumDescriptor(_PRIMTYPE)

PrimType = enum_type_wrapper.EnumTypeWrapper(_PRIMTYPE)
_PRIMCON = _descriptor.EnumDescriptor(
  name='PrimCon',
  full_name='daml_lf_1.PrimCon',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CON_UNIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CON_FALSE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CON_TRUE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8898,
  serialized_end=8950,
)
_sym_db.RegisterEnumDescriptor(_PRIMCON)

PrimCon = enum_type_wrapper.EnumTypeWrapper(_PRIMCON)
_BUILTINFUNCTION = _descriptor.EnumDescriptor(
  name='BuiltinFunction',
  full_name='daml_lf_1.BuiltinFunction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADD_DECIMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUB_DECIMAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUL_DECIMAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIV_DECIMAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROUND_DECIMAL', index=4, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD_INT64', index=5, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUB_INT64', index=6, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MUL_INT64', index=7, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIV_INT64', index=8, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOD_INT64', index=9, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXP_INT64', index=10, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FOLDL', index=11, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FOLDR', index=12, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP_EMPTY', index=13, number=96,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP_INSERT', index=14, number=97,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP_LOOKUP', index=15, number=98,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP_DELETE', index=16, number=99,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP_TO_LIST', index=17, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP_SIZE', index=18, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPLODE_TEXT', index=19, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPEND_TEXT', index=20, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=21, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEQ_INT64', index=22, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEQ_DECIMAL', index=23, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEQ_TEXT', index=24, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEQ_TIMESTAMP', index=25, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEQ_DATE', index=26, number=67,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEQ_PARTY', index=27, number=89,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_INT64', index=28, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_DECIMAL', index=29, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_TEXT', index=30, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_TIMESTAMP', index=31, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_DATE', index=32, number=68,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_PARTY', index=33, number=90,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEQ_INT64', index=34, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEQ_DECIMAL', index=35, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEQ_TEXT', index=36, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEQ_TIMESTAMP', index=37, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEQ_DATE', index=38, number=69,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEQ_PARTY', index=39, number=91,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_INT64', index=40, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_DECIMAL', index=41, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_TEXT', index=42, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_TIMESTAMP', index=43, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_DATE', index=44, number=70,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_PARTY', index=45, number=92,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_TEXT_INT64', index=46, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_TEXT_DECIMAL', index=47, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_TEXT_TEXT', index=48, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_TEXT_TIMESTAMP', index=49, number=61,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_TEXT_DATE', index=50, number=71,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_QUOTED_TEXT_PARTY', index=51, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_TEXT_PARTY', index=52, number=94,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TO_TEXT_CODE_POINTS', index=53, number=105,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FROM_TEXT_PARTY', index=54, number=95,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FROM_TEXT_INT64', index=55, number=103,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FROM_TEXT_DECIMAL', index=56, number=104,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FROM_TEXT_CODE_POINTS', index=57, number=106,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA256_TEXT', index=58, number=93,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_TO_UNIX_DAYS', index=59, number=72,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIX_DAYS_TO_DATE', index=60, number=73,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMESTAMP_TO_UNIX_MICROSECONDS', index=61, number=74,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIX_MICROSECONDS_TO_TIMESTAMP', index=62, number=75,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT64_TO_DECIMAL', index=63, number=76,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECIMAL_TO_INT64', index=64, number=77,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPLODE_TEXT', index=65, number=78,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_INT64', index=66, number=79,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_DECIMAL', index=67, number=80,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_TEXT', index=68, number=81,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_TIMESTAMP', index=69, number=82,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_DATE', index=70, number=83,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_PARTY', index=71, number=84,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_BOOL', index=72, number=85,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_CONTRACT_ID', index=73, number=86,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_LIST', index=74, number=87,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=75, number=88,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COERCE_CONTRACT_ID', index=76, number=102,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8953,
  serialized_end=10369,
)
_sym_db.RegisterEnumDescriptor(_BUILTINFUNCTION)

BuiltinFunction = enum_type_wrapper.EnumTypeWrapper(_BUILTINFUNCTION)
UNIT = 0
BOOL = 1
INT64 = 2
DECIMAL = 3
TEXT = 5
TIMESTAMP = 6
PARTY = 8
LIST = 9
UPDATE = 10
SCENARIO = 11
DATE = 12
CONTRACT_ID = 13
OPTIONAL = 14
ARROW = 15
MAP = 16
CON_UNIT = 0
CON_FALSE = 1
CON_TRUE = 2
ADD_DECIMAL = 0
SUB_DECIMAL = 1
MUL_DECIMAL = 2
DIV_DECIMAL = 3
ROUND_DECIMAL = 6
ADD_INT64 = 7
SUB_INT64 = 8
MUL_INT64 = 9
DIV_INT64 = 10
MOD_INT64 = 11
EXP_INT64 = 12
FOLDL = 20
FOLDR = 21
MAP_EMPTY = 96
MAP_INSERT = 97
MAP_LOOKUP = 98
MAP_DELETE = 99
MAP_TO_LIST = 100
MAP_SIZE = 101
EXPLODE_TEXT = 23
APPEND_TEXT = 24
ERROR = 25
LEQ_INT64 = 33
LEQ_DECIMAL = 34
LEQ_TEXT = 36
LEQ_TIMESTAMP = 37
LEQ_DATE = 67
LEQ_PARTY = 89
LESS_INT64 = 39
LESS_DECIMAL = 40
LESS_TEXT = 42
LESS_TIMESTAMP = 43
LESS_DATE = 68
LESS_PARTY = 90
GEQ_INT64 = 45
GEQ_DECIMAL = 46
GEQ_TEXT = 48
GEQ_TIMESTAMP = 49
GEQ_DATE = 69
GEQ_PARTY = 91
GREATER_INT64 = 51
GREATER_DECIMAL = 52
GREATER_TEXT = 54
GREATER_TIMESTAMP = 55
GREATER_DATE = 70
GREATER_PARTY = 92
TO_TEXT_INT64 = 57
TO_TEXT_DECIMAL = 58
TO_TEXT_TEXT = 60
TO_TEXT_TIMESTAMP = 61
TO_TEXT_DATE = 71
TO_QUOTED_TEXT_PARTY = 63
TO_TEXT_PARTY = 94
TO_TEXT_CODE_POINTS = 105
FROM_TEXT_PARTY = 95
FROM_TEXT_INT64 = 103
FROM_TEXT_DECIMAL = 104
FROM_TEXT_CODE_POINTS = 106
SHA256_TEXT = 93
DATE_TO_UNIX_DAYS = 72
UNIX_DAYS_TO_DATE = 73
TIMESTAMP_TO_UNIX_MICROSECONDS = 74
UNIX_MICROSECONDS_TO_TIMESTAMP = 75
INT64_TO_DECIMAL = 76
DECIMAL_TO_INT64 = 77
IMPLODE_TEXT = 78
EQUAL_INT64 = 79
EQUAL_DECIMAL = 80
EQUAL_TEXT = 81
EQUAL_TIMESTAMP = 82
EQUAL_DATE = 83
EQUAL_PARTY = 84
EQUAL_BOOL = 85
EQUAL_CONTRACT_ID = 86
EQUAL_LIST = 87
TRACE = 88
COERCE_CONTRACT_ID = 102



_UNIT = _descriptor.Descriptor(
  name='Unit',
  full_name='daml_lf_1.Unit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=39,
)


_PACKAGEREF = _descriptor.Descriptor(
  name='PackageRef',
  full_name='daml_lf_1.PackageRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='self', full_name='daml_lf_1.PackageRef.self', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='package_id', full_name='daml_lf_1.PackageRef.package_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.PackageRef.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=41,
  serialized_end=115,
)


_DOTTEDNAME = _descriptor.Descriptor(
  name='DottedName',
  full_name='daml_lf_1.DottedName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='segments', full_name='daml_lf_1.DottedName.segments', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=147,
)


_MODULEREF = _descriptor.Descriptor(
  name='ModuleRef',
  full_name='daml_lf_1.ModuleRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_ref', full_name='daml_lf_1.ModuleRef.package_ref', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='module_name', full_name='daml_lf_1.ModuleRef.module_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=248,
)


_TYPECONNAME = _descriptor.Descriptor(
  name='TypeConName',
  full_name='daml_lf_1.TypeConName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='module', full_name='daml_lf_1.TypeConName.module', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='daml_lf_1.TypeConName.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=338,
)


_VALNAME = _descriptor.Descriptor(
  name='ValName',
  full_name='daml_lf_1.ValName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='module', full_name='daml_lf_1.ValName.module', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='daml_lf_1.ValName.name', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=401,
)


_FIELDWITHTYPE = _descriptor.Descriptor(
  name='FieldWithType',
  full_name='daml_lf_1.FieldWithType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.FieldWithType.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.FieldWithType.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=464,
)


_VARWITHTYPE = _descriptor.Descriptor(
  name='VarWithType',
  full_name='daml_lf_1.VarWithType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='var', full_name='daml_lf_1.VarWithType.var', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.VarWithType.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=523,
)


_TYPEVARWITHKIND = _descriptor.Descriptor(
  name='TypeVarWithKind',
  full_name='daml_lf_1.TypeVarWithKind',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='var', full_name='daml_lf_1.TypeVarWithKind.var', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='daml_lf_1.TypeVarWithKind.kind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=586,
)


_FIELDWITHEXPR = _descriptor.Descriptor(
  name='FieldWithExpr',
  full_name='daml_lf_1.FieldWithExpr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.FieldWithExpr.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expr', full_name='daml_lf_1.FieldWithExpr.expr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=649,
)


_BINDING = _descriptor.Descriptor(
  name='Binding',
  full_name='daml_lf_1.Binding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='binder', full_name='daml_lf_1.Binding.binder', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bound', full_name='daml_lf_1.Binding.bound', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=732,
)


_KIND_ARROW = _descriptor.Descriptor(
  name='Arrow',
  full_name='daml_lf_1.Kind.Arrow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='daml_lf_1.Kind.Arrow.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='daml_lf_1.Kind.Arrow.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=889,
)

_KIND = _descriptor.Descriptor(
  name='Kind',
  full_name='daml_lf_1.Kind',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='star', full_name='daml_lf_1.Kind.star', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arrow', full_name='daml_lf_1.Kind.arrow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_KIND_ARROW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.Kind.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=735,
  serialized_end=896,
)


_TYPE_VAR = _descriptor.Descriptor(
  name='Var',
  full_name='daml_lf_1.Type.Var',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='var', full_name='daml_lf_1.Type.Var.var', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='daml_lf_1.Type.Var.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1184,
)

_TYPE_CON = _descriptor.Descriptor(
  name='Con',
  full_name='daml_lf_1.Type.Con',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.Type.Con.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='daml_lf_1.Type.Con.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1186,
  serialized_end=1261,
)

_TYPE_PRIM = _descriptor.Descriptor(
  name='Prim',
  full_name='daml_lf_1.Type.Prim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prim', full_name='daml_lf_1.Type.Prim.prim', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='daml_lf_1.Type.Prim.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1263,
  serialized_end=1335,
)

_TYPE_FUN = _descriptor.Descriptor(
  name='Fun',
  full_name='daml_lf_1.Type.Fun',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='daml_lf_1.Type.Fun.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='daml_lf_1.Type.Fun.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1337,
  serialized_end=1408,
)

_TYPE_FORALL = _descriptor.Descriptor(
  name='Forall',
  full_name='daml_lf_1.Type.Forall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vars', full_name='daml_lf_1.Type.Forall.vars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.Type.Forall.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1410,
  serialized_end=1491,
)

_TYPE_TUPLE = _descriptor.Descriptor(
  name='Tuple',
  full_name='daml_lf_1.Type.Tuple',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='daml_lf_1.Type.Tuple.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1542,
)

_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='daml_lf_1.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='var', full_name='daml_lf_1.Type.var', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='con', full_name='daml_lf_1.Type.con', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prim', full_name='daml_lf_1.Type.prim', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fun', full_name='daml_lf_1.Type.fun', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forall', full_name='daml_lf_1.Type.forall', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple', full_name='daml_lf_1.Type.tuple', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_VAR, _TYPE_CON, _TYPE_PRIM, _TYPE_FUN, _TYPE_FORALL, _TYPE_TUPLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.Type.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=899,
  serialized_end=1573,
)


_PRIMLIT = _descriptor.Descriptor(
  name='PrimLit',
  full_name='daml_lf_1.PrimLit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='int64', full_name='daml_lf_1.PrimLit.int64', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal', full_name='daml_lf_1.PrimLit.decimal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='daml_lf_1.PrimLit.text', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='daml_lf_1.PrimLit.timestamp', index=3,
      number=5, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='party', full_name='daml_lf_1.PrimLit.party', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='daml_lf_1.PrimLit.date', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.PrimLit.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1576,
  serialized_end=1710,
)


_LOCATION_RANGE = _descriptor.Descriptor(
  name='Range',
  full_name='daml_lf_1.Location.Range',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_line', full_name='daml_lf_1.Location.Range.start_line', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_col', full_name='daml_lf_1.Location.Range.start_col', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_line', full_name='daml_lf_1.Location.Range.end_line', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_col', full_name='daml_lf_1.Location.Range.end_col', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1886,
)

_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='daml_lf_1.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='module', full_name='daml_lf_1.Location.module', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='daml_lf_1.Location.range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LOCATION_RANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1713,
  serialized_end=1886,
)


_EXPR_RECCON = _descriptor.Descriptor(
  name='RecCon',
  full_name='daml_lf_1.Expr.RecCon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.Expr.RecCon.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='daml_lf_1.Expr.RecCon.fields', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2931,
  serialized_end=3017,
)

_EXPR_RECPROJ = _descriptor.Descriptor(
  name='RecProj',
  full_name='daml_lf_1.Expr.RecProj',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.Expr.RecProj.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.Expr.RecProj.field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='record', full_name='daml_lf_1.Expr.RecProj.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3019,
  serialized_end=3112,
)

_EXPR_RECUPD = _descriptor.Descriptor(
  name='RecUpd',
  full_name='daml_lf_1.Expr.RecUpd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.Expr.RecUpd.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.Expr.RecUpd.field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='record', full_name='daml_lf_1.Expr.RecUpd.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='daml_lf_1.Expr.RecUpd.update', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3114,
  serialized_end=3239,
)

_EXPR_VARIANTCON = _descriptor.Descriptor(
  name='VariantCon',
  full_name='daml_lf_1.Expr.VariantCon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.Expr.VariantCon.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant_con', full_name='daml_lf_1.Expr.VariantCon.variant_con', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant_arg', full_name='daml_lf_1.Expr.VariantCon.variant_arg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3241,
  serialized_end=3348,
)

_EXPR_ENUMCON = _descriptor.Descriptor(
  name='EnumCon',
  full_name='daml_lf_1.Expr.EnumCon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.Expr.EnumCon.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum_con', full_name='daml_lf_1.Expr.EnumCon.enum_con', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3350,
  serialized_end=3416,
)

_EXPR_TUPLECON = _descriptor.Descriptor(
  name='TupleCon',
  full_name='daml_lf_1.Expr.TupleCon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='daml_lf_1.Expr.TupleCon.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3418,
  serialized_end=3470,
)

_EXPR_TUPLEPROJ = _descriptor.Descriptor(
  name='TupleProj',
  full_name='daml_lf_1.Expr.TupleProj',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.Expr.TupleProj.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple', full_name='daml_lf_1.Expr.TupleProj.tuple', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3472,
  serialized_end=3530,
)

_EXPR_TUPLEUPD = _descriptor.Descriptor(
  name='TupleUpd',
  full_name='daml_lf_1.Expr.TupleUpd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.Expr.TupleUpd.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple', full_name='daml_lf_1.Expr.TupleUpd.tuple', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='daml_lf_1.Expr.TupleUpd.update', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3532,
  serialized_end=3622,
)

_EXPR_APP = _descriptor.Descriptor(
  name='App',
  full_name='daml_lf_1.Expr.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fun', full_name='daml_lf_1.Expr.App.fun', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='daml_lf_1.Expr.App.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3624,
  serialized_end=3690,
)

_EXPR_TYAPP = _descriptor.Descriptor(
  name='TyApp',
  full_name='daml_lf_1.Expr.TyApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expr', full_name='daml_lf_1.Expr.TyApp.expr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='types', full_name='daml_lf_1.Expr.TyApp.types', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3692,
  serialized_end=3762,
)

_EXPR_ABS = _descriptor.Descriptor(
  name='Abs',
  full_name='daml_lf_1.Expr.Abs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='param', full_name='daml_lf_1.Expr.Abs.param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.Expr.Abs.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3764,
  serialized_end=3839,
)

_EXPR_TYABS = _descriptor.Descriptor(
  name='TyAbs',
  full_name='daml_lf_1.Expr.TyAbs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='param', full_name='daml_lf_1.Expr.TyAbs.param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.Expr.TyAbs.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3841,
  serialized_end=3922,
)

_EXPR_NIL = _descriptor.Descriptor(
  name='Nil',
  full_name='daml_lf_1.Expr.Nil',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.Expr.Nil.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3924,
  serialized_end=3960,
)

_EXPR_CONS = _descriptor.Descriptor(
  name='Cons',
  full_name='daml_lf_1.Expr.Cons',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.Expr.Cons.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='front', full_name='daml_lf_1.Expr.Cons.front', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail', full_name='daml_lf_1.Expr.Cons.tail', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3962,
  serialized_end=4062,
)

_EXPR_NONE = _descriptor.Descriptor(
  name='None',
  full_name='daml_lf_1.Expr.None',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.Expr.None.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4064,
  serialized_end=4101,
)

_EXPR_SOME = _descriptor.Descriptor(
  name='Some',
  full_name='daml_lf_1.Expr.Some',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.Expr.Some.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.Expr.Some.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4103,
  serialized_end=4171,
)

_EXPR = _descriptor.Descriptor(
  name='Expr',
  full_name='daml_lf_1.Expr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='daml_lf_1.Expr.location', index=0,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var', full_name='daml_lf_1.Expr.var', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='daml_lf_1.Expr.val', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='builtin', full_name='daml_lf_1.Expr.builtin', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prim_con', full_name='daml_lf_1.Expr.prim_con', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prim_lit', full_name='daml_lf_1.Expr.prim_lit', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rec_con', full_name='daml_lf_1.Expr.rec_con', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rec_proj', full_name='daml_lf_1.Expr.rec_proj', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rec_upd', full_name='daml_lf_1.Expr.rec_upd', index=8,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant_con', full_name='daml_lf_1.Expr.variant_con', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum_con', full_name='daml_lf_1.Expr.enum_con', index=10,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple_con', full_name='daml_lf_1.Expr.tuple_con', index=11,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple_proj', full_name='daml_lf_1.Expr.tuple_proj', index=12,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tuple_upd', full_name='daml_lf_1.Expr.tuple_upd', index=13,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app', full_name='daml_lf_1.Expr.app', index=14,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ty_app', full_name='daml_lf_1.Expr.ty_app', index=15,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abs', full_name='daml_lf_1.Expr.abs', index=16,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ty_abs', full_name='daml_lf_1.Expr.ty_abs', index=17,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='case', full_name='daml_lf_1.Expr.case', index=18,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='let', full_name='daml_lf_1.Expr.let', index=19,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nil', full_name='daml_lf_1.Expr.nil', index=20,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cons', full_name='daml_lf_1.Expr.cons', index=21,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='daml_lf_1.Expr.update', index=22,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenario', full_name='daml_lf_1.Expr.scenario', index=23,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='none', full_name='daml_lf_1.Expr.none', index=24,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='some', full_name='daml_lf_1.Expr.some', index=25,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EXPR_RECCON, _EXPR_RECPROJ, _EXPR_RECUPD, _EXPR_VARIANTCON, _EXPR_ENUMCON, _EXPR_TUPLECON, _EXPR_TUPLEPROJ, _EXPR_TUPLEUPD, _EXPR_APP, _EXPR_TYAPP, _EXPR_ABS, _EXPR_TYABS, _EXPR_NIL, _EXPR_CONS, _EXPR_NONE, _EXPR_SOME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.Expr.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1889,
  serialized_end=4190,
)


_CASEALT_VARIANT = _descriptor.Descriptor(
  name='Variant',
  full_name='daml_lf_1.CaseAlt.Variant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='con', full_name='daml_lf_1.CaseAlt.Variant.con', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant', full_name='daml_lf_1.CaseAlt.Variant.variant', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binder', full_name='daml_lf_1.CaseAlt.Variant.binder', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4546,
  serialized_end=4625,
)

_CASEALT_ENUM = _descriptor.Descriptor(
  name='Enum',
  full_name='daml_lf_1.CaseAlt.Enum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='con', full_name='daml_lf_1.CaseAlt.Enum.con', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constructor', full_name='daml_lf_1.CaseAlt.Enum.constructor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4627,
  serialized_end=4691,
)

_CASEALT_CONS = _descriptor.Descriptor(
  name='Cons',
  full_name='daml_lf_1.CaseAlt.Cons',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='var_head', full_name='daml_lf_1.CaseAlt.Cons.var_head', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var_tail', full_name='daml_lf_1.CaseAlt.Cons.var_tail', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4693,
  serialized_end=4735,
)

_CASEALT_SOME = _descriptor.Descriptor(
  name='Some',
  full_name='daml_lf_1.CaseAlt.Some',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='var_body', full_name='daml_lf_1.CaseAlt.Some.var_body', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4737,
  serialized_end=4761,
)

_CASEALT = _descriptor.Descriptor(
  name='CaseAlt',
  full_name='daml_lf_1.CaseAlt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default', full_name='daml_lf_1.CaseAlt.default', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant', full_name='daml_lf_1.CaseAlt.variant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prim_con', full_name='daml_lf_1.CaseAlt.prim_con', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nil', full_name='daml_lf_1.CaseAlt.nil', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cons', full_name='daml_lf_1.CaseAlt.cons', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='none', full_name='daml_lf_1.CaseAlt.none', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='some', full_name='daml_lf_1.CaseAlt.some', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum', full_name='daml_lf_1.CaseAlt.enum', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.CaseAlt.body', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CASEALT_VARIANT, _CASEALT_ENUM, _CASEALT_CONS, _CASEALT_SOME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.CaseAlt.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=4193,
  serialized_end=4768,
)


_CASE = _descriptor.Descriptor(
  name='Case',
  full_name='daml_lf_1.Case',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scrut', full_name='daml_lf_1.Case.scrut', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alts', full_name='daml_lf_1.Case.alts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4770,
  serialized_end=4842,
)


_BLOCK = _descriptor.Descriptor(
  name='Block',
  full_name='daml_lf_1.Block',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bindings', full_name='daml_lf_1.Block.bindings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.Block.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4844,
  serialized_end=4920,
)


_PURE = _descriptor.Descriptor(
  name='Pure',
  full_name='daml_lf_1.Pure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.Pure.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expr', full_name='daml_lf_1.Pure.expr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4922,
  serialized_end=4990,
)


_UPDATE_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='daml_lf_1.Update.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='daml_lf_1.Update.Create.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expr', full_name='daml_lf_1.Update.Create.expr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5408,
  serialized_end=5489,
)

_UPDATE_EXERCISE = _descriptor.Descriptor(
  name='Exercise',
  full_name='daml_lf_1.Update.Exercise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='daml_lf_1.Update.Exercise.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='choice', full_name='daml_lf_1.Update.Exercise.choice', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cid', full_name='daml_lf_1.Update.Exercise.cid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor', full_name='daml_lf_1.Update.Exercise.actor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='daml_lf_1.Update.Exercise.arg', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5492,
  serialized_end=5652,
)

_UPDATE_FETCH = _descriptor.Descriptor(
  name='Fetch',
  full_name='daml_lf_1.Update.Fetch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='daml_lf_1.Update.Fetch.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cid', full_name='daml_lf_1.Update.Fetch.cid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5654,
  serialized_end=5739,
)

_UPDATE_EMBEDEXPR = _descriptor.Descriptor(
  name='EmbedExpr',
  full_name='daml_lf_1.Update.EmbedExpr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.Update.EmbedExpr.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.Update.EmbedExpr.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5741,
  serialized_end=5814,
)

_UPDATE_RETRIEVEBYKEY = _descriptor.Descriptor(
  name='RetrieveByKey',
  full_name='daml_lf_1.Update.RetrieveByKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='daml_lf_1.Update.RetrieveByKey.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='daml_lf_1.Update.RetrieveByKey.key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5816,
  serialized_end=5903,
)

_UPDATE = _descriptor.Descriptor(
  name='Update',
  full_name='daml_lf_1.Update',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pure', full_name='daml_lf_1.Update.pure', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='daml_lf_1.Update.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='daml_lf_1.Update.create', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exercise', full_name='daml_lf_1.Update.exercise', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch', full_name='daml_lf_1.Update.fetch', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_time', full_name='daml_lf_1.Update.get_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lookup_by_key', full_name='daml_lf_1.Update.lookup_by_key', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch_by_key', full_name='daml_lf_1.Update.fetch_by_key', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='embed_expr', full_name='daml_lf_1.Update.embed_expr', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATE_CREATE, _UPDATE_EXERCISE, _UPDATE_FETCH, _UPDATE_EMBEDEXPR, _UPDATE_RETRIEVEBYKEY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.Update.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=4993,
  serialized_end=5910,
)


_SCENARIO_COMMIT = _descriptor.Descriptor(
  name='Commit',
  full_name='daml_lf_1.Scenario.Commit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party', full_name='daml_lf_1.Scenario.Commit.party', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expr', full_name='daml_lf_1.Scenario.Commit.expr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ret_type', full_name='daml_lf_1.Scenario.Commit.ret_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6250,
  serialized_end=6356,
)

_SCENARIO_EMBEDEXPR = _descriptor.Descriptor(
  name='EmbedExpr',
  full_name='daml_lf_1.Scenario.EmbedExpr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.Scenario.EmbedExpr.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='daml_lf_1.Scenario.EmbedExpr.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5741,
  serialized_end=5814,
)

_SCENARIO = _descriptor.Descriptor(
  name='Scenario',
  full_name='daml_lf_1.Scenario',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pure', full_name='daml_lf_1.Scenario.pure', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='daml_lf_1.Scenario.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='daml_lf_1.Scenario.commit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mustFailAt', full_name='daml_lf_1.Scenario.mustFailAt', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pass', full_name='daml_lf_1.Scenario.pass', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_time', full_name='daml_lf_1.Scenario.get_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_party', full_name='daml_lf_1.Scenario.get_party', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='embed_expr', full_name='daml_lf_1.Scenario.embed_expr', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SCENARIO_COMMIT, _SCENARIO_EMBEDEXPR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.Scenario.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5913,
  serialized_end=6438,
)


_TEMPLATECHOICE = _descriptor.Descriptor(
  name='TemplateChoice',
  full_name='daml_lf_1.TemplateChoice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='daml_lf_1.TemplateChoice.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consuming', full_name='daml_lf_1.TemplateChoice.consuming', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controllers', full_name='daml_lf_1.TemplateChoice.controllers', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg_binder', full_name='daml_lf_1.TemplateChoice.arg_binder', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ret_type', full_name='daml_lf_1.TemplateChoice.ret_type', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='daml_lf_1.TemplateChoice.update', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='self_binder', full_name='daml_lf_1.TemplateChoice.self_binder', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='daml_lf_1.TemplateChoice.location', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6441,
  serialized_end=6700,
)


_KEYEXPR_PROJECTION = _descriptor.Descriptor(
  name='Projection',
  full_name='daml_lf_1.KeyExpr.Projection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.KeyExpr.Projection.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.KeyExpr.Projection.field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6814,
  serialized_end=6877,
)

_KEYEXPR_PROJECTIONS = _descriptor.Descriptor(
  name='Projections',
  full_name='daml_lf_1.KeyExpr.Projections',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projections', full_name='daml_lf_1.KeyExpr.Projections.projections', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6879,
  serialized_end=6944,
)

_KEYEXPR_RECORDFIELD = _descriptor.Descriptor(
  name='RecordField',
  full_name='daml_lf_1.KeyExpr.RecordField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='daml_lf_1.KeyExpr.RecordField.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expr', full_name='daml_lf_1.KeyExpr.RecordField.expr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6946,
  serialized_end=7008,
)

_KEYEXPR_RECORD = _descriptor.Descriptor(
  name='Record',
  full_name='daml_lf_1.KeyExpr.Record',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.KeyExpr.Record.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='daml_lf_1.KeyExpr.Record.fields', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7010,
  serialized_end=7102,
)

_KEYEXPR = _descriptor.Descriptor(
  name='KeyExpr',
  full_name='daml_lf_1.KeyExpr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projections', full_name='daml_lf_1.KeyExpr.projections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='record', full_name='daml_lf_1.KeyExpr.record', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_KEYEXPR_PROJECTION, _KEYEXPR_PROJECTIONS, _KEYEXPR_RECORDFIELD, _KEYEXPR_RECORD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Sum', full_name='daml_lf_1.KeyExpr.Sum',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6703,
  serialized_end=7109,
)


_DEFTEMPLATE_DEFKEY = _descriptor.Descriptor(
  name='DefKey',
  full_name='daml_lf_1.DefTemplate.DefKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.DefTemplate.DefKey.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='daml_lf_1.DefTemplate.DefKey.key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='complex_key', full_name='daml_lf_1.DefTemplate.DefKey.complex_key', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maintainers', full_name='daml_lf_1.DefTemplate.DefKey.maintainers', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='key_expr', full_name='daml_lf_1.DefTemplate.DefKey.key_expr',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=7452,
  serialized_end=7616,
)

_DEFTEMPLATE = _descriptor.Descriptor(
  name='DefTemplate',
  full_name='daml_lf_1.DefTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tycon', full_name='daml_lf_1.DefTemplate.tycon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param', full_name='daml_lf_1.DefTemplate.param', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precond', full_name='daml_lf_1.DefTemplate.precond', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signatories', full_name='daml_lf_1.DefTemplate.signatories', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agreement', full_name='daml_lf_1.DefTemplate.agreement', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='choices', full_name='daml_lf_1.DefTemplate.choices', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observers', full_name='daml_lf_1.DefTemplate.observers', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='daml_lf_1.DefTemplate.location', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='daml_lf_1.DefTemplate.key', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEFTEMPLATE_DEFKEY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7112,
  serialized_end=7622,
)


_DEFDATATYPE_FIELDS = _descriptor.Descriptor(
  name='Fields',
  full_name='daml_lf_1.DefDataType.Fields',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='daml_lf_1.DefDataType.Fields.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7938,
  serialized_end=7988,
)

_DEFDATATYPE_ENUMCONSTRUCTORS = _descriptor.Descriptor(
  name='EnumConstructors',
  full_name='daml_lf_1.DefDataType.EnumConstructors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='constructors', full_name='daml_lf_1.DefDataType.EnumConstructors.constructors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7990,
  serialized_end=8030,
)

_DEFDATATYPE = _descriptor.Descriptor(
  name='DefDataType',
  full_name='daml_lf_1.DefDataType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='daml_lf_1.DefDataType.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='daml_lf_1.DefDataType.params', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='record', full_name='daml_lf_1.DefDataType.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variant', full_name='daml_lf_1.DefDataType.variant', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum', full_name='daml_lf_1.DefDataType.enum', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serializable', full_name='daml_lf_1.DefDataType.serializable', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='daml_lf_1.DefDataType.location', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEFDATATYPE_FIELDS, _DEFDATATYPE_ENUMCONSTRUCTORS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='DataCons', full_name='daml_lf_1.DefDataType.DataCons',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=7625,
  serialized_end=8042,
)


_DEFVALUE_NAMEWITHTYPE = _descriptor.Descriptor(
  name='NameWithType',
  full_name='daml_lf_1.DefValue.NameWithType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='daml_lf_1.DefValue.NameWithType.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='daml_lf_1.DefValue.NameWithType.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8229,
  serialized_end=8288,
)

_DEFVALUE = _descriptor.Descriptor(
  name='DefValue',
  full_name='daml_lf_1.DefValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name_with_type', full_name='daml_lf_1.DefValue.name_with_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expr', full_name='daml_lf_1.DefValue.expr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_party_literals', full_name='daml_lf_1.DefValue.no_party_literals', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_test', full_name='daml_lf_1.DefValue.is_test', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='daml_lf_1.DefValue.location', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEFVALUE_NAMEWITHTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8045,
  serialized_end=8288,
)


_FEATUREFLAGS = _descriptor.Descriptor(
  name='FeatureFlags',
  full_name='daml_lf_1.FeatureFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='forbidPartyLiterals', full_name='daml_lf_1.FeatureFlags.forbidPartyLiterals', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dontDivulgeContractIdsInCreateArguments', full_name='daml_lf_1.FeatureFlags.dontDivulgeContractIdsInCreateArguments', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dontDiscloseNonConsumingChoicesToObservers', full_name='daml_lf_1.FeatureFlags.dontDiscloseNonConsumingChoicesToObservers', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8291,
  serialized_end=8435,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='daml_lf_1.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='daml_lf_1.Module.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='daml_lf_1.Module.flags', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_types', full_name='daml_lf_1.Module.data_types', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='daml_lf_1.Module.values', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templates', full_name='daml_lf_1.Module.templates', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8438,
  serialized_end=8659,
)


_PACKAGE = _descriptor.Descriptor(
  name='Package',
  full_name='daml_lf_1.Package',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modules', full_name='daml_lf_1.Package.modules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8661,
  serialized_end=8706,
)

_PACKAGEREF.fields_by_name['self'].message_type = _UNIT
_PACKAGEREF.oneofs_by_name['Sum'].fields.append(
  _PACKAGEREF.fields_by_name['self'])
_PACKAGEREF.fields_by_name['self'].containing_oneof = _PACKAGEREF.oneofs_by_name['Sum']
_PACKAGEREF.oneofs_by_name['Sum'].fields.append(
  _PACKAGEREF.fields_by_name['package_id'])
_PACKAGEREF.fields_by_name['package_id'].containing_oneof = _PACKAGEREF.oneofs_by_name['Sum']
_MODULEREF.fields_by_name['package_ref'].message_type = _PACKAGEREF
_MODULEREF.fields_by_name['module_name'].message_type = _DOTTEDNAME
_TYPECONNAME.fields_by_name['module'].message_type = _MODULEREF
_TYPECONNAME.fields_by_name['name'].message_type = _DOTTEDNAME
_VALNAME.fields_by_name['module'].message_type = _MODULEREF
_FIELDWITHTYPE.fields_by_name['type'].message_type = _TYPE
_VARWITHTYPE.fields_by_name['type'].message_type = _TYPE
_TYPEVARWITHKIND.fields_by_name['kind'].message_type = _KIND
_FIELDWITHEXPR.fields_by_name['expr'].message_type = _EXPR
_BINDING.fields_by_name['binder'].message_type = _VARWITHTYPE
_BINDING.fields_by_name['bound'].message_type = _EXPR
_KIND_ARROW.fields_by_name['params'].message_type = _KIND
_KIND_ARROW.fields_by_name['result'].message_type = _KIND
_KIND_ARROW.containing_type = _KIND
_KIND.fields_by_name['star'].message_type = _UNIT
_KIND.fields_by_name['arrow'].message_type = _KIND_ARROW
_KIND.oneofs_by_name['Sum'].fields.append(
  _KIND.fields_by_name['star'])
_KIND.fields_by_name['star'].containing_oneof = _KIND.oneofs_by_name['Sum']
_KIND.oneofs_by_name['Sum'].fields.append(
  _KIND.fields_by_name['arrow'])
_KIND.fields_by_name['arrow'].containing_oneof = _KIND.oneofs_by_name['Sum']
_TYPE_VAR.fields_by_name['args'].message_type = _TYPE
_TYPE_VAR.containing_type = _TYPE
_TYPE_CON.fields_by_name['tycon'].message_type = _TYPECONNAME
_TYPE_CON.fields_by_name['args'].message_type = _TYPE
_TYPE_CON.containing_type = _TYPE
_TYPE_PRIM.fields_by_name['prim'].enum_type = _PRIMTYPE
_TYPE_PRIM.fields_by_name['args'].message_type = _TYPE
_TYPE_PRIM.containing_type = _TYPE
_TYPE_FUN.fields_by_name['params'].message_type = _TYPE
_TYPE_FUN.fields_by_name['result'].message_type = _TYPE
_TYPE_FUN.containing_type = _TYPE
_TYPE_FORALL.fields_by_name['vars'].message_type = _TYPEVARWITHKIND
_TYPE_FORALL.fields_by_name['body'].message_type = _TYPE
_TYPE_FORALL.containing_type = _TYPE
_TYPE_TUPLE.fields_by_name['fields'].message_type = _FIELDWITHTYPE
_TYPE_TUPLE.containing_type = _TYPE
_TYPE.fields_by_name['var'].message_type = _TYPE_VAR
_TYPE.fields_by_name['con'].message_type = _TYPE_CON
_TYPE.fields_by_name['prim'].message_type = _TYPE_PRIM
_TYPE.fields_by_name['fun'].message_type = _TYPE_FUN
_TYPE.fields_by_name['forall'].message_type = _TYPE_FORALL
_TYPE.fields_by_name['tuple'].message_type = _TYPE_TUPLE
_TYPE.oneofs_by_name['Sum'].fields.append(
  _TYPE.fields_by_name['var'])
_TYPE.fields_by_name['var'].containing_oneof = _TYPE.oneofs_by_name['Sum']
_TYPE.oneofs_by_name['Sum'].fields.append(
  _TYPE.fields_by_name['con'])
_TYPE.fields_by_name['con'].containing_oneof = _TYPE.oneofs_by_name['Sum']
_TYPE.oneofs_by_name['Sum'].fields.append(
  _TYPE.fields_by_name['prim'])
_TYPE.fields_by_name['prim'].containing_oneof = _TYPE.oneofs_by_name['Sum']
_TYPE.oneofs_by_name['Sum'].fields.append(
  _TYPE.fields_by_name['fun'])
_TYPE.fields_by_name['fun'].containing_oneof = _TYPE.oneofs_by_name['Sum']
_TYPE.oneofs_by_name['Sum'].fields.append(
  _TYPE.fields_by_name['forall'])
_TYPE.fields_by_name['forall'].containing_oneof = _TYPE.oneofs_by_name['Sum']
_TYPE.oneofs_by_name['Sum'].fields.append(
  _TYPE.fields_by_name['tuple'])
_TYPE.fields_by_name['tuple'].containing_oneof = _TYPE.oneofs_by_name['Sum']
_PRIMLIT.oneofs_by_name['Sum'].fields.append(
  _PRIMLIT.fields_by_name['int64'])
_PRIMLIT.fields_by_name['int64'].containing_oneof = _PRIMLIT.oneofs_by_name['Sum']
_PRIMLIT.oneofs_by_name['Sum'].fields.append(
  _PRIMLIT.fields_by_name['decimal'])
_PRIMLIT.fields_by_name['decimal'].containing_oneof = _PRIMLIT.oneofs_by_name['Sum']
_PRIMLIT.oneofs_by_name['Sum'].fields.append(
  _PRIMLIT.fields_by_name['text'])
_PRIMLIT.fields_by_name['text'].containing_oneof = _PRIMLIT.oneofs_by_name['Sum']
_PRIMLIT.oneofs_by_name['Sum'].fields.append(
  _PRIMLIT.fields_by_name['timestamp'])
_PRIMLIT.fields_by_name['timestamp'].containing_oneof = _PRIMLIT.oneofs_by_name['Sum']
_PRIMLIT.oneofs_by_name['Sum'].fields.append(
  _PRIMLIT.fields_by_name['party'])
_PRIMLIT.fields_by_name['party'].containing_oneof = _PRIMLIT.oneofs_by_name['Sum']
_PRIMLIT.oneofs_by_name['Sum'].fields.append(
  _PRIMLIT.fields_by_name['date'])
_PRIMLIT.fields_by_name['date'].containing_oneof = _PRIMLIT.oneofs_by_name['Sum']
_LOCATION_RANGE.containing_type = _LOCATION
_LOCATION.fields_by_name['module'].message_type = _MODULEREF
_LOCATION.fields_by_name['range'].message_type = _LOCATION_RANGE
_EXPR_RECCON.fields_by_name['tycon'].message_type = _TYPE_CON
_EXPR_RECCON.fields_by_name['fields'].message_type = _FIELDWITHEXPR
_EXPR_RECCON.containing_type = _EXPR
_EXPR_RECPROJ.fields_by_name['tycon'].message_type = _TYPE_CON
_EXPR_RECPROJ.fields_by_name['record'].message_type = _EXPR
_EXPR_RECPROJ.containing_type = _EXPR
_EXPR_RECUPD.fields_by_name['tycon'].message_type = _TYPE_CON
_EXPR_RECUPD.fields_by_name['record'].message_type = _EXPR
_EXPR_RECUPD.fields_by_name['update'].message_type = _EXPR
_EXPR_RECUPD.containing_type = _EXPR
_EXPR_VARIANTCON.fields_by_name['tycon'].message_type = _TYPE_CON
_EXPR_VARIANTCON.fields_by_name['variant_arg'].message_type = _EXPR
_EXPR_VARIANTCON.containing_type = _EXPR
_EXPR_ENUMCON.fields_by_name['tycon'].message_type = _TYPECONNAME
_EXPR_ENUMCON.containing_type = _EXPR
_EXPR_TUPLECON.fields_by_name['fields'].message_type = _FIELDWITHEXPR
_EXPR_TUPLECON.containing_type = _EXPR
_EXPR_TUPLEPROJ.fields_by_name['tuple'].message_type = _EXPR
_EXPR_TUPLEPROJ.containing_type = _EXPR
_EXPR_TUPLEUPD.fields_by_name['tuple'].message_type = _EXPR
_EXPR_TUPLEUPD.fields_by_name['update'].message_type = _EXPR
_EXPR_TUPLEUPD.containing_type = _EXPR
_EXPR_APP.fields_by_name['fun'].message_type = _EXPR
_EXPR_APP.fields_by_name['args'].message_type = _EXPR
_EXPR_APP.containing_type = _EXPR
_EXPR_TYAPP.fields_by_name['expr'].message_type = _EXPR
_EXPR_TYAPP.fields_by_name['types'].message_type = _TYPE
_EXPR_TYAPP.containing_type = _EXPR
_EXPR_ABS.fields_by_name['param'].message_type = _VARWITHTYPE
_EXPR_ABS.fields_by_name['body'].message_type = _EXPR
_EXPR_ABS.containing_type = _EXPR
_EXPR_TYABS.fields_by_name['param'].message_type = _TYPEVARWITHKIND
_EXPR_TYABS.fields_by_name['body'].message_type = _EXPR
_EXPR_TYABS.containing_type = _EXPR
_EXPR_NIL.fields_by_name['type'].message_type = _TYPE
_EXPR_NIL.containing_type = _EXPR
_EXPR_CONS.fields_by_name['type'].message_type = _TYPE
_EXPR_CONS.fields_by_name['front'].message_type = _EXPR
_EXPR_CONS.fields_by_name['tail'].message_type = _EXPR
_EXPR_CONS.containing_type = _EXPR
_EXPR_NONE.fields_by_name['type'].message_type = _TYPE
_EXPR_NONE.containing_type = _EXPR
_EXPR_SOME.fields_by_name['type'].message_type = _TYPE
_EXPR_SOME.fields_by_name['body'].message_type = _EXPR
_EXPR_SOME.containing_type = _EXPR
_EXPR.fields_by_name['location'].message_type = _LOCATION
_EXPR.fields_by_name['val'].message_type = _VALNAME
_EXPR.fields_by_name['builtin'].enum_type = _BUILTINFUNCTION
_EXPR.fields_by_name['prim_con'].enum_type = _PRIMCON
_EXPR.fields_by_name['prim_lit'].message_type = _PRIMLIT
_EXPR.fields_by_name['rec_con'].message_type = _EXPR_RECCON
_EXPR.fields_by_name['rec_proj'].message_type = _EXPR_RECPROJ
_EXPR.fields_by_name['rec_upd'].message_type = _EXPR_RECUPD
_EXPR.fields_by_name['variant_con'].message_type = _EXPR_VARIANTCON
_EXPR.fields_by_name['enum_con'].message_type = _EXPR_ENUMCON
_EXPR.fields_by_name['tuple_con'].message_type = _EXPR_TUPLECON
_EXPR.fields_by_name['tuple_proj'].message_type = _EXPR_TUPLEPROJ
_EXPR.fields_by_name['tuple_upd'].message_type = _EXPR_TUPLEUPD
_EXPR.fields_by_name['app'].message_type = _EXPR_APP
_EXPR.fields_by_name['ty_app'].message_type = _EXPR_TYAPP
_EXPR.fields_by_name['abs'].message_type = _EXPR_ABS
_EXPR.fields_by_name['ty_abs'].message_type = _EXPR_TYABS
_EXPR.fields_by_name['case'].message_type = _CASE
_EXPR.fields_by_name['let'].message_type = _BLOCK
_EXPR.fields_by_name['nil'].message_type = _EXPR_NIL
_EXPR.fields_by_name['cons'].message_type = _EXPR_CONS
_EXPR.fields_by_name['update'].message_type = _UPDATE
_EXPR.fields_by_name['scenario'].message_type = _SCENARIO
_EXPR.fields_by_name['none'].message_type = _EXPR_NONE
_EXPR.fields_by_name['some'].message_type = _EXPR_SOME
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['var'])
_EXPR.fields_by_name['var'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['val'])
_EXPR.fields_by_name['val'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['builtin'])
_EXPR.fields_by_name['builtin'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['prim_con'])
_EXPR.fields_by_name['prim_con'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['prim_lit'])
_EXPR.fields_by_name['prim_lit'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['rec_con'])
_EXPR.fields_by_name['rec_con'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['rec_proj'])
_EXPR.fields_by_name['rec_proj'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['rec_upd'])
_EXPR.fields_by_name['rec_upd'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['variant_con'])
_EXPR.fields_by_name['variant_con'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['enum_con'])
_EXPR.fields_by_name['enum_con'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['tuple_con'])
_EXPR.fields_by_name['tuple_con'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['tuple_proj'])
_EXPR.fields_by_name['tuple_proj'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['tuple_upd'])
_EXPR.fields_by_name['tuple_upd'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['app'])
_EXPR.fields_by_name['app'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['ty_app'])
_EXPR.fields_by_name['ty_app'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['abs'])
_EXPR.fields_by_name['abs'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['ty_abs'])
_EXPR.fields_by_name['ty_abs'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['case'])
_EXPR.fields_by_name['case'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['let'])
_EXPR.fields_by_name['let'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['nil'])
_EXPR.fields_by_name['nil'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['cons'])
_EXPR.fields_by_name['cons'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['update'])
_EXPR.fields_by_name['update'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['scenario'])
_EXPR.fields_by_name['scenario'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['none'])
_EXPR.fields_by_name['none'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_EXPR.oneofs_by_name['Sum'].fields.append(
  _EXPR.fields_by_name['some'])
_EXPR.fields_by_name['some'].containing_oneof = _EXPR.oneofs_by_name['Sum']
_CASEALT_VARIANT.fields_by_name['con'].message_type = _TYPECONNAME
_CASEALT_VARIANT.containing_type = _CASEALT
_CASEALT_ENUM.fields_by_name['con'].message_type = _TYPECONNAME
_CASEALT_ENUM.containing_type = _CASEALT
_CASEALT_CONS.containing_type = _CASEALT
_CASEALT_SOME.containing_type = _CASEALT
_CASEALT.fields_by_name['default'].message_type = _UNIT
_CASEALT.fields_by_name['variant'].message_type = _CASEALT_VARIANT
_CASEALT.fields_by_name['prim_con'].enum_type = _PRIMCON
_CASEALT.fields_by_name['nil'].message_type = _UNIT
_CASEALT.fields_by_name['cons'].message_type = _CASEALT_CONS
_CASEALT.fields_by_name['none'].message_type = _UNIT
_CASEALT.fields_by_name['some'].message_type = _CASEALT_SOME
_CASEALT.fields_by_name['enum'].message_type = _CASEALT_ENUM
_CASEALT.fields_by_name['body'].message_type = _EXPR
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['default'])
_CASEALT.fields_by_name['default'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['variant'])
_CASEALT.fields_by_name['variant'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['prim_con'])
_CASEALT.fields_by_name['prim_con'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['nil'])
_CASEALT.fields_by_name['nil'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['cons'])
_CASEALT.fields_by_name['cons'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['none'])
_CASEALT.fields_by_name['none'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['some'])
_CASEALT.fields_by_name['some'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASEALT.oneofs_by_name['Sum'].fields.append(
  _CASEALT.fields_by_name['enum'])
_CASEALT.fields_by_name['enum'].containing_oneof = _CASEALT.oneofs_by_name['Sum']
_CASE.fields_by_name['scrut'].message_type = _EXPR
_CASE.fields_by_name['alts'].message_type = _CASEALT
_BLOCK.fields_by_name['bindings'].message_type = _BINDING
_BLOCK.fields_by_name['body'].message_type = _EXPR
_PURE.fields_by_name['type'].message_type = _TYPE
_PURE.fields_by_name['expr'].message_type = _EXPR
_UPDATE_CREATE.fields_by_name['template'].message_type = _TYPECONNAME
_UPDATE_CREATE.fields_by_name['expr'].message_type = _EXPR
_UPDATE_CREATE.containing_type = _UPDATE
_UPDATE_EXERCISE.fields_by_name['template'].message_type = _TYPECONNAME
_UPDATE_EXERCISE.fields_by_name['cid'].message_type = _EXPR
_UPDATE_EXERCISE.fields_by_name['actor'].message_type = _EXPR
_UPDATE_EXERCISE.fields_by_name['arg'].message_type = _EXPR
_UPDATE_EXERCISE.containing_type = _UPDATE
_UPDATE_FETCH.fields_by_name['template'].message_type = _TYPECONNAME
_UPDATE_FETCH.fields_by_name['cid'].message_type = _EXPR
_UPDATE_FETCH.containing_type = _UPDATE
_UPDATE_EMBEDEXPR.fields_by_name['type'].message_type = _TYPE
_UPDATE_EMBEDEXPR.fields_by_name['body'].message_type = _EXPR
_UPDATE_EMBEDEXPR.containing_type = _UPDATE
_UPDATE_RETRIEVEBYKEY.fields_by_name['template'].message_type = _TYPECONNAME
_UPDATE_RETRIEVEBYKEY.fields_by_name['key'].message_type = _EXPR
_UPDATE_RETRIEVEBYKEY.containing_type = _UPDATE
_UPDATE.fields_by_name['pure'].message_type = _PURE
_UPDATE.fields_by_name['block'].message_type = _BLOCK
_UPDATE.fields_by_name['create'].message_type = _UPDATE_CREATE
_UPDATE.fields_by_name['exercise'].message_type = _UPDATE_EXERCISE
_UPDATE.fields_by_name['fetch'].message_type = _UPDATE_FETCH
_UPDATE.fields_by_name['get_time'].message_type = _UNIT
_UPDATE.fields_by_name['lookup_by_key'].message_type = _UPDATE_RETRIEVEBYKEY
_UPDATE.fields_by_name['fetch_by_key'].message_type = _UPDATE_RETRIEVEBYKEY
_UPDATE.fields_by_name['embed_expr'].message_type = _UPDATE_EMBEDEXPR
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['pure'])
_UPDATE.fields_by_name['pure'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['block'])
_UPDATE.fields_by_name['block'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['create'])
_UPDATE.fields_by_name['create'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['exercise'])
_UPDATE.fields_by_name['exercise'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['fetch'])
_UPDATE.fields_by_name['fetch'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['get_time'])
_UPDATE.fields_by_name['get_time'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['lookup_by_key'])
_UPDATE.fields_by_name['lookup_by_key'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['fetch_by_key'])
_UPDATE.fields_by_name['fetch_by_key'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_UPDATE.oneofs_by_name['Sum'].fields.append(
  _UPDATE.fields_by_name['embed_expr'])
_UPDATE.fields_by_name['embed_expr'].containing_oneof = _UPDATE.oneofs_by_name['Sum']
_SCENARIO_COMMIT.fields_by_name['party'].message_type = _EXPR
_SCENARIO_COMMIT.fields_by_name['expr'].message_type = _EXPR
_SCENARIO_COMMIT.fields_by_name['ret_type'].message_type = _TYPE
_SCENARIO_COMMIT.containing_type = _SCENARIO
_SCENARIO_EMBEDEXPR.fields_by_name['type'].message_type = _TYPE
_SCENARIO_EMBEDEXPR.fields_by_name['body'].message_type = _EXPR
_SCENARIO_EMBEDEXPR.containing_type = _SCENARIO
_SCENARIO.fields_by_name['pure'].message_type = _PURE
_SCENARIO.fields_by_name['block'].message_type = _BLOCK
_SCENARIO.fields_by_name['commit'].message_type = _SCENARIO_COMMIT
_SCENARIO.fields_by_name['mustFailAt'].message_type = _SCENARIO_COMMIT
_SCENARIO.fields_by_name['pass'].message_type = _EXPR
_SCENARIO.fields_by_name['get_time'].message_type = _UNIT
_SCENARIO.fields_by_name['get_party'].message_type = _EXPR
_SCENARIO.fields_by_name['embed_expr'].message_type = _SCENARIO_EMBEDEXPR
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['pure'])
_SCENARIO.fields_by_name['pure'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['block'])
_SCENARIO.fields_by_name['block'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['commit'])
_SCENARIO.fields_by_name['commit'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['mustFailAt'])
_SCENARIO.fields_by_name['mustFailAt'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['pass'])
_SCENARIO.fields_by_name['pass'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['get_time'])
_SCENARIO.fields_by_name['get_time'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['get_party'])
_SCENARIO.fields_by_name['get_party'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_SCENARIO.oneofs_by_name['Sum'].fields.append(
  _SCENARIO.fields_by_name['embed_expr'])
_SCENARIO.fields_by_name['embed_expr'].containing_oneof = _SCENARIO.oneofs_by_name['Sum']
_TEMPLATECHOICE.fields_by_name['controllers'].message_type = _EXPR
_TEMPLATECHOICE.fields_by_name['arg_binder'].message_type = _VARWITHTYPE
_TEMPLATECHOICE.fields_by_name['ret_type'].message_type = _TYPE
_TEMPLATECHOICE.fields_by_name['update'].message_type = _EXPR
_TEMPLATECHOICE.fields_by_name['location'].message_type = _LOCATION
_KEYEXPR_PROJECTION.fields_by_name['tycon'].message_type = _TYPE_CON
_KEYEXPR_PROJECTION.containing_type = _KEYEXPR
_KEYEXPR_PROJECTIONS.fields_by_name['projections'].message_type = _KEYEXPR_PROJECTION
_KEYEXPR_PROJECTIONS.containing_type = _KEYEXPR
_KEYEXPR_RECORDFIELD.fields_by_name['expr'].message_type = _KEYEXPR
_KEYEXPR_RECORDFIELD.containing_type = _KEYEXPR
_KEYEXPR_RECORD.fields_by_name['tycon'].message_type = _TYPE_CON
_KEYEXPR_RECORD.fields_by_name['fields'].message_type = _KEYEXPR_RECORDFIELD
_KEYEXPR_RECORD.containing_type = _KEYEXPR
_KEYEXPR.fields_by_name['projections'].message_type = _KEYEXPR_PROJECTIONS
_KEYEXPR.fields_by_name['record'].message_type = _KEYEXPR_RECORD
_KEYEXPR.oneofs_by_name['Sum'].fields.append(
  _KEYEXPR.fields_by_name['projections'])
_KEYEXPR.fields_by_name['projections'].containing_oneof = _KEYEXPR.oneofs_by_name['Sum']
_KEYEXPR.oneofs_by_name['Sum'].fields.append(
  _KEYEXPR.fields_by_name['record'])
_KEYEXPR.fields_by_name['record'].containing_oneof = _KEYEXPR.oneofs_by_name['Sum']
_DEFTEMPLATE_DEFKEY.fields_by_name['type'].message_type = _TYPE
_DEFTEMPLATE_DEFKEY.fields_by_name['key'].message_type = _KEYEXPR
_DEFTEMPLATE_DEFKEY.fields_by_name['complex_key'].message_type = _EXPR
_DEFTEMPLATE_DEFKEY.fields_by_name['maintainers'].message_type = _EXPR
_DEFTEMPLATE_DEFKEY.containing_type = _DEFTEMPLATE
_DEFTEMPLATE_DEFKEY.oneofs_by_name['key_expr'].fields.append(
  _DEFTEMPLATE_DEFKEY.fields_by_name['key'])
_DEFTEMPLATE_DEFKEY.fields_by_name['key'].containing_oneof = _DEFTEMPLATE_DEFKEY.oneofs_by_name['key_expr']
_DEFTEMPLATE_DEFKEY.oneofs_by_name['key_expr'].fields.append(
  _DEFTEMPLATE_DEFKEY.fields_by_name['complex_key'])
_DEFTEMPLATE_DEFKEY.fields_by_name['complex_key'].containing_oneof = _DEFTEMPLATE_DEFKEY.oneofs_by_name['key_expr']
_DEFTEMPLATE.fields_by_name['tycon'].message_type = _DOTTEDNAME
_DEFTEMPLATE.fields_by_name['precond'].message_type = _EXPR
_DEFTEMPLATE.fields_by_name['signatories'].message_type = _EXPR
_DEFTEMPLATE.fields_by_name['agreement'].message_type = _EXPR
_DEFTEMPLATE.fields_by_name['choices'].message_type = _TEMPLATECHOICE
_DEFTEMPLATE.fields_by_name['observers'].message_type = _EXPR
_DEFTEMPLATE.fields_by_name['location'].message_type = _LOCATION
_DEFTEMPLATE.fields_by_name['key'].message_type = _DEFTEMPLATE_DEFKEY
_DEFDATATYPE_FIELDS.fields_by_name['fields'].message_type = _FIELDWITHTYPE
_DEFDATATYPE_FIELDS.containing_type = _DEFDATATYPE
_DEFDATATYPE_ENUMCONSTRUCTORS.containing_type = _DEFDATATYPE
_DEFDATATYPE.fields_by_name['name'].message_type = _DOTTEDNAME
_DEFDATATYPE.fields_by_name['params'].message_type = _TYPEVARWITHKIND
_DEFDATATYPE.fields_by_name['record'].message_type = _DEFDATATYPE_FIELDS
_DEFDATATYPE.fields_by_name['variant'].message_type = _DEFDATATYPE_FIELDS
_DEFDATATYPE.fields_by_name['enum'].message_type = _DEFDATATYPE_ENUMCONSTRUCTORS
_DEFDATATYPE.fields_by_name['location'].message_type = _LOCATION
_DEFDATATYPE.oneofs_by_name['DataCons'].fields.append(
  _DEFDATATYPE.fields_by_name['record'])
_DEFDATATYPE.fields_by_name['record'].containing_oneof = _DEFDATATYPE.oneofs_by_name['DataCons']
_DEFDATATYPE.oneofs_by_name['DataCons'].fields.append(
  _DEFDATATYPE.fields_by_name['variant'])
_DEFDATATYPE.fields_by_name['variant'].containing_oneof = _DEFDATATYPE.oneofs_by_name['DataCons']
_DEFDATATYPE.oneofs_by_name['DataCons'].fields.append(
  _DEFDATATYPE.fields_by_name['enum'])
_DEFDATATYPE.fields_by_name['enum'].containing_oneof = _DEFDATATYPE.oneofs_by_name['DataCons']
_DEFVALUE_NAMEWITHTYPE.fields_by_name['type'].message_type = _TYPE
_DEFVALUE_NAMEWITHTYPE.containing_type = _DEFVALUE
_DEFVALUE.fields_by_name['name_with_type'].message_type = _DEFVALUE_NAMEWITHTYPE
_DEFVALUE.fields_by_name['expr'].message_type = _EXPR
_DEFVALUE.fields_by_name['location'].message_type = _LOCATION
_MODULE.fields_by_name['name'].message_type = _DOTTEDNAME
_MODULE.fields_by_name['flags'].message_type = _FEATUREFLAGS
_MODULE.fields_by_name['data_types'].message_type = _DEFDATATYPE
_MODULE.fields_by_name['values'].message_type = _DEFVALUE
_MODULE.fields_by_name['templates'].message_type = _DEFTEMPLATE
_PACKAGE.fields_by_name['modules'].message_type = _MODULE
DESCRIPTOR.message_types_by_name['Unit'] = _UNIT
DESCRIPTOR.message_types_by_name['PackageRef'] = _PACKAGEREF
DESCRIPTOR.message_types_by_name['DottedName'] = _DOTTEDNAME
DESCRIPTOR.message_types_by_name['ModuleRef'] = _MODULEREF
DESCRIPTOR.message_types_by_name['TypeConName'] = _TYPECONNAME
DESCRIPTOR.message_types_by_name['ValName'] = _VALNAME
DESCRIPTOR.message_types_by_name['FieldWithType'] = _FIELDWITHTYPE
DESCRIPTOR.message_types_by_name['VarWithType'] = _VARWITHTYPE
DESCRIPTOR.message_types_by_name['TypeVarWithKind'] = _TYPEVARWITHKIND
DESCRIPTOR.message_types_by_name['FieldWithExpr'] = _FIELDWITHEXPR
DESCRIPTOR.message_types_by_name['Binding'] = _BINDING
DESCRIPTOR.message_types_by_name['Kind'] = _KIND
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
DESCRIPTOR.message_types_by_name['PrimLit'] = _PRIMLIT
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
DESCRIPTOR.message_types_by_name['Expr'] = _EXPR
DESCRIPTOR.message_types_by_name['CaseAlt'] = _CASEALT
DESCRIPTOR.message_types_by_name['Case'] = _CASE
DESCRIPTOR.message_types_by_name['Block'] = _BLOCK
DESCRIPTOR.message_types_by_name['Pure'] = _PURE
DESCRIPTOR.message_types_by_name['Update'] = _UPDATE
DESCRIPTOR.message_types_by_name['Scenario'] = _SCENARIO
DESCRIPTOR.message_types_by_name['TemplateChoice'] = _TEMPLATECHOICE
DESCRIPTOR.message_types_by_name['KeyExpr'] = _KEYEXPR
DESCRIPTOR.message_types_by_name['DefTemplate'] = _DEFTEMPLATE
DESCRIPTOR.message_types_by_name['DefDataType'] = _DEFDATATYPE
DESCRIPTOR.message_types_by_name['DefValue'] = _DEFVALUE
DESCRIPTOR.message_types_by_name['FeatureFlags'] = _FEATUREFLAGS
DESCRIPTOR.message_types_by_name['Module'] = _MODULE
DESCRIPTOR.message_types_by_name['Package'] = _PACKAGE
DESCRIPTOR.enum_types_by_name['PrimType'] = _PRIMTYPE
DESCRIPTOR.enum_types_by_name['PrimCon'] = _PRIMCON
DESCRIPTOR.enum_types_by_name['BuiltinFunction'] = _BUILTINFUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Unit = _reflection.GeneratedProtocolMessageType('Unit', (_message.Message,), dict(
  DESCRIPTOR = _UNIT,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Unit)
  ))
_sym_db.RegisterMessage(Unit)

PackageRef = _reflection.GeneratedProtocolMessageType('PackageRef', (_message.Message,), dict(
  DESCRIPTOR = _PACKAGEREF,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.PackageRef)
  ))
_sym_db.RegisterMessage(PackageRef)

DottedName = _reflection.GeneratedProtocolMessageType('DottedName', (_message.Message,), dict(
  DESCRIPTOR = _DOTTEDNAME,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.DottedName)
  ))
_sym_db.RegisterMessage(DottedName)

ModuleRef = _reflection.GeneratedProtocolMessageType('ModuleRef', (_message.Message,), dict(
  DESCRIPTOR = _MODULEREF,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.ModuleRef)
  ))
_sym_db.RegisterMessage(ModuleRef)

TypeConName = _reflection.GeneratedProtocolMessageType('TypeConName', (_message.Message,), dict(
  DESCRIPTOR = _TYPECONNAME,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.TypeConName)
  ))
_sym_db.RegisterMessage(TypeConName)

ValName = _reflection.GeneratedProtocolMessageType('ValName', (_message.Message,), dict(
  DESCRIPTOR = _VALNAME,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.ValName)
  ))
_sym_db.RegisterMessage(ValName)

FieldWithType = _reflection.GeneratedProtocolMessageType('FieldWithType', (_message.Message,), dict(
  DESCRIPTOR = _FIELDWITHTYPE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.FieldWithType)
  ))
_sym_db.RegisterMessage(FieldWithType)

VarWithType = _reflection.GeneratedProtocolMessageType('VarWithType', (_message.Message,), dict(
  DESCRIPTOR = _VARWITHTYPE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.VarWithType)
  ))
_sym_db.RegisterMessage(VarWithType)

TypeVarWithKind = _reflection.GeneratedProtocolMessageType('TypeVarWithKind', (_message.Message,), dict(
  DESCRIPTOR = _TYPEVARWITHKIND,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.TypeVarWithKind)
  ))
_sym_db.RegisterMessage(TypeVarWithKind)

FieldWithExpr = _reflection.GeneratedProtocolMessageType('FieldWithExpr', (_message.Message,), dict(
  DESCRIPTOR = _FIELDWITHEXPR,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.FieldWithExpr)
  ))
_sym_db.RegisterMessage(FieldWithExpr)

Binding = _reflection.GeneratedProtocolMessageType('Binding', (_message.Message,), dict(
  DESCRIPTOR = _BINDING,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Binding)
  ))
_sym_db.RegisterMessage(Binding)

Kind = _reflection.GeneratedProtocolMessageType('Kind', (_message.Message,), dict(

  Arrow = _reflection.GeneratedProtocolMessageType('Arrow', (_message.Message,), dict(
    DESCRIPTOR = _KIND_ARROW,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Kind.Arrow)
    ))
  ,
  DESCRIPTOR = _KIND,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Kind)
  ))
_sym_db.RegisterMessage(Kind)
_sym_db.RegisterMessage(Kind.Arrow)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), dict(

  Var = _reflection.GeneratedProtocolMessageType('Var', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_VAR,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Type.Var)
    ))
  ,

  Con = _reflection.GeneratedProtocolMessageType('Con', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_CON,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Type.Con)
    ))
  ,

  Prim = _reflection.GeneratedProtocolMessageType('Prim', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_PRIM,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Type.Prim)
    ))
  ,

  Fun = _reflection.GeneratedProtocolMessageType('Fun', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_FUN,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Type.Fun)
    ))
  ,

  Forall = _reflection.GeneratedProtocolMessageType('Forall', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_FORALL,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Type.Forall)
    ))
  ,

  Tuple = _reflection.GeneratedProtocolMessageType('Tuple', (_message.Message,), dict(
    DESCRIPTOR = _TYPE_TUPLE,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Type.Tuple)
    ))
  ,
  DESCRIPTOR = _TYPE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Type)
  ))
_sym_db.RegisterMessage(Type)
_sym_db.RegisterMessage(Type.Var)
_sym_db.RegisterMessage(Type.Con)
_sym_db.RegisterMessage(Type.Prim)
_sym_db.RegisterMessage(Type.Fun)
_sym_db.RegisterMessage(Type.Forall)
_sym_db.RegisterMessage(Type.Tuple)

PrimLit = _reflection.GeneratedProtocolMessageType('PrimLit', (_message.Message,), dict(
  DESCRIPTOR = _PRIMLIT,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.PrimLit)
  ))
_sym_db.RegisterMessage(PrimLit)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), dict(

  Range = _reflection.GeneratedProtocolMessageType('Range', (_message.Message,), dict(
    DESCRIPTOR = _LOCATION_RANGE,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Location.Range)
    ))
  ,
  DESCRIPTOR = _LOCATION,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Location)
  ))
_sym_db.RegisterMessage(Location)
_sym_db.RegisterMessage(Location.Range)

Expr = _reflection.GeneratedProtocolMessageType('Expr', (_message.Message,), dict(

  RecCon = _reflection.GeneratedProtocolMessageType('RecCon', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_RECCON,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.RecCon)
    ))
  ,

  RecProj = _reflection.GeneratedProtocolMessageType('RecProj', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_RECPROJ,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.RecProj)
    ))
  ,

  RecUpd = _reflection.GeneratedProtocolMessageType('RecUpd', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_RECUPD,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.RecUpd)
    ))
  ,

  VariantCon = _reflection.GeneratedProtocolMessageType('VariantCon', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_VARIANTCON,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.VariantCon)
    ))
  ,

  EnumCon = _reflection.GeneratedProtocolMessageType('EnumCon', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_ENUMCON,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.EnumCon)
    ))
  ,

  TupleCon = _reflection.GeneratedProtocolMessageType('TupleCon', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_TUPLECON,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.TupleCon)
    ))
  ,

  TupleProj = _reflection.GeneratedProtocolMessageType('TupleProj', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_TUPLEPROJ,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.TupleProj)
    ))
  ,

  TupleUpd = _reflection.GeneratedProtocolMessageType('TupleUpd', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_TUPLEUPD,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.TupleUpd)
    ))
  ,

  App = _reflection.GeneratedProtocolMessageType('App', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_APP,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.App)
    ))
  ,

  TyApp = _reflection.GeneratedProtocolMessageType('TyApp', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_TYAPP,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.TyApp)
    ))
  ,

  Abs = _reflection.GeneratedProtocolMessageType('Abs', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_ABS,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.Abs)
    ))
  ,

  TyAbs = _reflection.GeneratedProtocolMessageType('TyAbs', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_TYABS,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.TyAbs)
    ))
  ,

  Nil = _reflection.GeneratedProtocolMessageType('Nil', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_NIL,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.Nil)
    ))
  ,

  Cons = _reflection.GeneratedProtocolMessageType('Cons', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_CONS,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.Cons)
    ))
  ,

  None_ = _reflection.GeneratedProtocolMessageType('None', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_NONE,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.None)
    ))
  ,

  Some = _reflection.GeneratedProtocolMessageType('Some', (_message.Message,), dict(
    DESCRIPTOR = _EXPR_SOME,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Expr.Some)
    ))
  ,
  DESCRIPTOR = _EXPR,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Expr)
  ))
_sym_db.RegisterMessage(Expr)
_sym_db.RegisterMessage(Expr.RecCon)
_sym_db.RegisterMessage(Expr.RecProj)
_sym_db.RegisterMessage(Expr.RecUpd)
_sym_db.RegisterMessage(Expr.VariantCon)
_sym_db.RegisterMessage(Expr.EnumCon)
_sym_db.RegisterMessage(Expr.TupleCon)
_sym_db.RegisterMessage(Expr.TupleProj)
_sym_db.RegisterMessage(Expr.TupleUpd)
_sym_db.RegisterMessage(Expr.App)
_sym_db.RegisterMessage(Expr.TyApp)
_sym_db.RegisterMessage(Expr.Abs)
_sym_db.RegisterMessage(Expr.TyAbs)
_sym_db.RegisterMessage(Expr.Nil)
_sym_db.RegisterMessage(Expr.Cons)
_sym_db.RegisterMessage(Expr.None_)
_sym_db.RegisterMessage(Expr.Some)

CaseAlt = _reflection.GeneratedProtocolMessageType('CaseAlt', (_message.Message,), dict(

  Variant = _reflection.GeneratedProtocolMessageType('Variant', (_message.Message,), dict(
    DESCRIPTOR = _CASEALT_VARIANT,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.CaseAlt.Variant)
    ))
  ,

  Enum = _reflection.GeneratedProtocolMessageType('Enum', (_message.Message,), dict(
    DESCRIPTOR = _CASEALT_ENUM,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.CaseAlt.Enum)
    ))
  ,

  Cons = _reflection.GeneratedProtocolMessageType('Cons', (_message.Message,), dict(
    DESCRIPTOR = _CASEALT_CONS,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.CaseAlt.Cons)
    ))
  ,

  Some = _reflection.GeneratedProtocolMessageType('Some', (_message.Message,), dict(
    DESCRIPTOR = _CASEALT_SOME,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.CaseAlt.Some)
    ))
  ,
  DESCRIPTOR = _CASEALT,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.CaseAlt)
  ))
_sym_db.RegisterMessage(CaseAlt)
_sym_db.RegisterMessage(CaseAlt.Variant)
_sym_db.RegisterMessage(CaseAlt.Enum)
_sym_db.RegisterMessage(CaseAlt.Cons)
_sym_db.RegisterMessage(CaseAlt.Some)

Case = _reflection.GeneratedProtocolMessageType('Case', (_message.Message,), dict(
  DESCRIPTOR = _CASE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Case)
  ))
_sym_db.RegisterMessage(Case)

Block = _reflection.GeneratedProtocolMessageType('Block', (_message.Message,), dict(
  DESCRIPTOR = _BLOCK,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Block)
  ))
_sym_db.RegisterMessage(Block)

Pure = _reflection.GeneratedProtocolMessageType('Pure', (_message.Message,), dict(
  DESCRIPTOR = _PURE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Pure)
  ))
_sym_db.RegisterMessage(Pure)

Update = _reflection.GeneratedProtocolMessageType('Update', (_message.Message,), dict(

  Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(
    DESCRIPTOR = _UPDATE_CREATE,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Update.Create)
    ))
  ,

  Exercise = _reflection.GeneratedProtocolMessageType('Exercise', (_message.Message,), dict(
    DESCRIPTOR = _UPDATE_EXERCISE,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Update.Exercise)
    ))
  ,

  Fetch = _reflection.GeneratedProtocolMessageType('Fetch', (_message.Message,), dict(
    DESCRIPTOR = _UPDATE_FETCH,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Update.Fetch)
    ))
  ,

  EmbedExpr = _reflection.GeneratedProtocolMessageType('EmbedExpr', (_message.Message,), dict(
    DESCRIPTOR = _UPDATE_EMBEDEXPR,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Update.EmbedExpr)
    ))
  ,

  RetrieveByKey = _reflection.GeneratedProtocolMessageType('RetrieveByKey', (_message.Message,), dict(
    DESCRIPTOR = _UPDATE_RETRIEVEBYKEY,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Update.RetrieveByKey)
    ))
  ,
  DESCRIPTOR = _UPDATE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Update)
  ))
_sym_db.RegisterMessage(Update)
_sym_db.RegisterMessage(Update.Create)
_sym_db.RegisterMessage(Update.Exercise)
_sym_db.RegisterMessage(Update.Fetch)
_sym_db.RegisterMessage(Update.EmbedExpr)
_sym_db.RegisterMessage(Update.RetrieveByKey)

Scenario = _reflection.GeneratedProtocolMessageType('Scenario', (_message.Message,), dict(

  Commit = _reflection.GeneratedProtocolMessageType('Commit', (_message.Message,), dict(
    DESCRIPTOR = _SCENARIO_COMMIT,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Scenario.Commit)
    ))
  ,

  EmbedExpr = _reflection.GeneratedProtocolMessageType('EmbedExpr', (_message.Message,), dict(
    DESCRIPTOR = _SCENARIO_EMBEDEXPR,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.Scenario.EmbedExpr)
    ))
  ,
  DESCRIPTOR = _SCENARIO,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Scenario)
  ))
_sym_db.RegisterMessage(Scenario)
_sym_db.RegisterMessage(Scenario.Commit)
_sym_db.RegisterMessage(Scenario.EmbedExpr)

TemplateChoice = _reflection.GeneratedProtocolMessageType('TemplateChoice', (_message.Message,), dict(
  DESCRIPTOR = _TEMPLATECHOICE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.TemplateChoice)
  ))
_sym_db.RegisterMessage(TemplateChoice)

KeyExpr = _reflection.GeneratedProtocolMessageType('KeyExpr', (_message.Message,), dict(

  Projection = _reflection.GeneratedProtocolMessageType('Projection', (_message.Message,), dict(
    DESCRIPTOR = _KEYEXPR_PROJECTION,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.KeyExpr.Projection)
    ))
  ,

  Projections = _reflection.GeneratedProtocolMessageType('Projections', (_message.Message,), dict(
    DESCRIPTOR = _KEYEXPR_PROJECTIONS,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.KeyExpr.Projections)
    ))
  ,

  RecordField = _reflection.GeneratedProtocolMessageType('RecordField', (_message.Message,), dict(
    DESCRIPTOR = _KEYEXPR_RECORDFIELD,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.KeyExpr.RecordField)
    ))
  ,

  Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), dict(
    DESCRIPTOR = _KEYEXPR_RECORD,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.KeyExpr.Record)
    ))
  ,
  DESCRIPTOR = _KEYEXPR,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.KeyExpr)
  ))
_sym_db.RegisterMessage(KeyExpr)
_sym_db.RegisterMessage(KeyExpr.Projection)
_sym_db.RegisterMessage(KeyExpr.Projections)
_sym_db.RegisterMessage(KeyExpr.RecordField)
_sym_db.RegisterMessage(KeyExpr.Record)

DefTemplate = _reflection.GeneratedProtocolMessageType('DefTemplate', (_message.Message,), dict(

  DefKey = _reflection.GeneratedProtocolMessageType('DefKey', (_message.Message,), dict(
    DESCRIPTOR = _DEFTEMPLATE_DEFKEY,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.DefTemplate.DefKey)
    ))
  ,
  DESCRIPTOR = _DEFTEMPLATE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.DefTemplate)
  ))
_sym_db.RegisterMessage(DefTemplate)
_sym_db.RegisterMessage(DefTemplate.DefKey)

DefDataType = _reflection.GeneratedProtocolMessageType('DefDataType', (_message.Message,), dict(

  Fields = _reflection.GeneratedProtocolMessageType('Fields', (_message.Message,), dict(
    DESCRIPTOR = _DEFDATATYPE_FIELDS,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.DefDataType.Fields)
    ))
  ,

  EnumConstructors = _reflection.GeneratedProtocolMessageType('EnumConstructors', (_message.Message,), dict(
    DESCRIPTOR = _DEFDATATYPE_ENUMCONSTRUCTORS,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.DefDataType.EnumConstructors)
    ))
  ,
  DESCRIPTOR = _DEFDATATYPE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.DefDataType)
  ))
_sym_db.RegisterMessage(DefDataType)
_sym_db.RegisterMessage(DefDataType.Fields)
_sym_db.RegisterMessage(DefDataType.EnumConstructors)

DefValue = _reflection.GeneratedProtocolMessageType('DefValue', (_message.Message,), dict(

  NameWithType = _reflection.GeneratedProtocolMessageType('NameWithType', (_message.Message,), dict(
    DESCRIPTOR = _DEFVALUE_NAMEWITHTYPE,
    __module__ = 'da.daml_lf_1_pb2'
    # @@protoc_insertion_point(class_scope:daml_lf_1.DefValue.NameWithType)
    ))
  ,
  DESCRIPTOR = _DEFVALUE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.DefValue)
  ))
_sym_db.RegisterMessage(DefValue)
_sym_db.RegisterMessage(DefValue.NameWithType)

FeatureFlags = _reflection.GeneratedProtocolMessageType('FeatureFlags', (_message.Message,), dict(
  DESCRIPTOR = _FEATUREFLAGS,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.FeatureFlags)
  ))
_sym_db.RegisterMessage(FeatureFlags)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), dict(
  DESCRIPTOR = _MODULE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Module)
  ))
_sym_db.RegisterMessage(Module)

Package = _reflection.GeneratedProtocolMessageType('Package', (_message.Message,), dict(
  DESCRIPTOR = _PACKAGE,
  __module__ = 'da.daml_lf_1_pb2'
  # @@protoc_insertion_point(class_scope:daml_lf_1.Package)
  ))
_sym_db.RegisterMessage(Package)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
